@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 1999-2002 Bernd Gehrmann <bernd@mail.berlios.de>
- * Copyright (c) 2003-2007 André Wöbbeking <Woebbeking@kde.org>
+ * Copyright (c) 2003-2008 André Wöbbeking <Woebbeking@kde.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,13 +24,14 @@
 
 #include <qdir.h>
 #include <qpainter.h>
-#include <qregexp.h>
+//Added by qt3to4:
+#include <QPixmap>
+#include <QTextStream>
 
 #include <kdebug.h>
-#include <kglobalsettings.h>
+#include <kcolorscheme.h>
 #include <kiconloader.h>
 #include <klocale.h>
-#include <kmimetype.h>
 
 #include "cvsdir.h"
 #include "entry.h"
@@ -70,7 +71,7 @@ QString UpdateItem::dirPath() const
 QString UpdateItem::filePath() const
 {
     // the filePath of the root item is '.'
-    return parent() ? dirPath() + m_entry.m_name : QChar('.');
+    return parent() ? dirPath() + m_entry.m_name : QLatin1String(".");
 }
 
 
@@ -154,7 +155,8 @@ void UpdateDirItem::updateEntriesItem(const Entry& entry,
             }
             fileItem->setRevTag(entry.m_revision, entry.m_tag);
             fileItem->setDate(entry.m_dateTime);
-            fileItem->setPixmap(0, isBinary ? SmallIcon("binary") : QPixmap());
+            fileItem->setPixmap(0, isBinary ? SmallIcon("application-octet-stream") 
+	                                    : QPixmap());
         }
         return;
     }
@@ -178,12 +180,11 @@ void UpdateDirItem::scanDirectory()
     const QFileInfoList *files = dir.entryInfoList();
     if (files)
     {
-        QFileInfoListIterator it(*files);
-        for (; it.current(); ++it)
+        Q_FOREACH (QFileInfo info, *files)
         {
             Entry entry;
-            entry.m_name = it.current()->fileName();
-            if (it.current()->isDir())
+            entry.m_name = info.fileName();
+            if (info.isDir())
             {
                 entry.m_type = Entry::Dir;
                 createDirItem(entry);
@@ -217,13 +218,12 @@ UpdateFileItem* UpdateDirItem::createFileItem(const Entry& entry)
 
 UpdateItem* UpdateDirItem::insertItem(UpdateItem* item)
 {
-    QPair<TMapItemsByName::iterator, bool> result
-        = m_itemsByName.insert(TMapItemsByName::value_type(item->entry().m_name, item));
-    if (!result.second)
+    const TMapItemsByName::iterator it = m_itemsByName.find(item->entry().m_name);
+    if (it != m_itemsByName.end())
     {
         // OK, an item with that name already exists. If the item type is the
         // same then keep the old one to preserve it's status information
-        UpdateItem* existingItem = *result.first;
+        UpdateItem* existingItem = *it;
         if (existingItem->rtti() == item->rtti())
         {
             delete item;
@@ -235,9 +235,13 @@ UpdateItem* UpdateDirItem::insertItem(UpdateItem* item)
             updateView()->replaceItem(existingItem, item);
 
             delete existingItem;
-            *result.first = item;
+            *it = item;
         }
     }
+    else
+    {
+        m_itemsByName.insert(item->entry().m_name, item);
+    }
 
     return item;
 }
@@ -250,53 +254,6 @@ UpdateItem* UpdateDirItem::findItem(const QString& name) const
     return (it != m_itemsByName.end()) ? *it : 0;
 }
 
-// Qt-3.3.8 changed the parsing in QDateTime::fromString() but introduced
-// a bug which leads to the problem that days with 1 digit will incorrectly being
-// parsed as day 0 - which is invalid.
-// workaround with the implementation from Qt-3.3.6
-QDateTime parseDateTime(const QString &s)
-{
-        static const char * const qt_shortMonthNames[] = {
-	"Jan", "Feb", "Mar", "Apr", "May", "Jun",
-	"Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
-
-	QString monthName( s.mid( 4, 3 ) );
-	int month = -1;
-	// Assume that English monthnames are the default
-	for ( int i = 0; i < 12; ++i ) {
-	    if ( monthName == qt_shortMonthNames[i] ) {
-		month = i + 1;
-		break;
-	    }
-	}
-	// If English names can't be found, search the localized ones
-	if ( month == -1 ) {
-	    for ( int i = 1; i <= 12; ++i ) {
-		if ( monthName == QDate::shortMonthName( i ) ) {
-		    month = i;
-		    break;
-		}
-	    }
-	}
-	if ( month < 1 || month > 12 ) {
-	    qWarning( "QDateTime::fromString: Parameter out of range" );
-	    QDateTime dt;
-	    return dt;
-	}
-	int day = s.mid( 8, 2 ).simplifyWhiteSpace().toInt();
-	int year = s.right( 4 ).toInt();
-	QDate date( year, month, day );
-	QTime time;
-	int hour, minute, second;
-	int pivot = s.find( QRegExp(QString::fromLatin1("[0-9][0-9]:[0-9][0-9]:[0-9][0-9]")) );
-	if ( pivot != -1 ) {
-	    hour = s.mid( pivot, 2 ).toInt();
-	    minute = s.mid( pivot+3, 2 ).toInt();
-	    second = s.mid( pivot+6, 2 ).toInt();
-	    time.setHMS( hour, minute, second );
-	}
-	return QDateTime( date, time );
-}
 
 // Format of the CVS/Entries file:
 //   /NAME/REVISION/[CONFLICT+]TIMESTAMP/OPTIONS/TAGDATE
@@ -306,10 +263,10 @@ void UpdateDirItem::syncWithEntries()
     const QString path(filePath() + QDir::separator());
 
     QFile f(path + "CVS/Entries");
-    if( f.open(IO_ReadOnly) )
+    if( f.open(QIODevice::ReadOnly) )
     {
         QTextStream stream(&f);
-        while( !stream.eof() )
+        while( !stream.atEnd() )
         {
             QString line = stream.readLine();
 
@@ -337,7 +294,7 @@ void UpdateDirItem::syncWithEntries()
                 const QString options(line.section('/', 4, 4));
                 entry.m_tag = line.section('/', 5, 5);
 
-                const bool isBinary(options.find("-kb") >= 0);
+                const bool isBinary = options.contains("-kb");
 
                 // file date in local time
                 entry.m_dateTime = QFileInfo(path + entry.m_name).lastModified();
@@ -349,17 +306,15 @@ void UpdateDirItem::syncWithEntries()
                     entry.m_status = Cervisia::LocallyRemoved;
                     rev.remove(0, 1);
                 }
-                else if (timestamp.find('+') >= 0)
+                else if (timestamp.contains('+'))
                 {
                     entry.m_status = Cervisia::Conflict;
                 }
                 else
                 {
-                    // workaround Qt-3.3.8 bug with our own function (see function above)
-                    // const QDateTime date(QDateTime::fromString(timestamp)); // UTC Time
-                    const QDateTime date(parseDateTime(timestamp)); // UTC Time
-                    QDateTime fileDateUTC;
-                    fileDateUTC.setTime_t(entry.m_dateTime.toTime_t(), Qt::UTC);
+                    QDateTime date(QDateTime::fromString(timestamp)); // UTC Time
+                    date.setTimeSpec(Qt::UTC);
+                    const QDateTime fileDateUTC(entry.m_dateTime.toUTC());
                     if (date != fileDateUTC)
                         entry.m_status = Cervisia::LocallyModified;
                 }
@@ -393,7 +348,7 @@ void UpdateDirItem::syncWithDirectory()
             if (!dir.exists(it.key()))
             {
                 fileItem->setStatus(Cervisia::Removed);
-                fileItem->setRevTag(QString::null, QString::null);
+                fileItem->setRevTag(QString(), QString());
             }
         }
     }
@@ -460,11 +415,11 @@ void UpdateDirItem::setOpen(bool open)
             view->setFilter(view->filter());
     }
 
-    QListViewItem::setOpen(open);
+    Q3ListViewItem::setOpen(open);
 }
 
 
-int UpdateDirItem::compare(QListViewItem* i,
+int UpdateDirItem::compare(Q3ListViewItem* i,
                            int /*column*/,
                            bool bAscending) const
 {
@@ -525,8 +480,8 @@ bool UpdateFileItem::applyFilter(UpdateView::Filter filter)
     bool visible(true);
     if (filter & UpdateView::OnlyDirectories)
         visible = false;
-    
-    bool unmodified = (entry().m_status == Cervisia::UpToDate) || 
+
+    bool unmodified = (entry().m_status == Cervisia::UpToDate) ||
                       (entry().m_status == Cervisia::Unknown);
     if ((filter & UpdateView::NoUpToDate) && unmodified)
         visible = false;
@@ -649,7 +604,7 @@ int UpdateFileItem::statusClass() const
 }
 
 
-int UpdateFileItem::compare(QListViewItem* i,
+int UpdateFileItem::compare(Q3ListViewItem* i,
                             int column,
                             bool bAscending) const
 {
@@ -665,9 +620,6 @@ int UpdateFileItem::compare(QListViewItem* i,
     case Name:
         iResult = entry().m_name.localeAwareCompare(item->entry().m_name);
         break;
-    case MimeType:
-        iResult = KMimeType::findByPath(entry().m_name)->comment().localeAwareCompare(KMimeType::findByPath(item->entry().m_name)->comment());
-        break;
     case Status:
         if ((iResult = ::compare(statusClass(), item->statusClass())) == 0)
             iResult = entry().m_name.localeAwareCompare(item->entry().m_name);
@@ -695,9 +647,6 @@ QString UpdateFileItem::text(int column) const
     case Name:
         result = entry().m_name;
         break;
-    case MimeType:
-	result = KMimeType::findByPath(entry().m_name)->comment();
-	break;
     case Status:
         result = toString(entry().m_status);
         break;
@@ -754,15 +703,15 @@ void UpdateFileItem::paintCell(QPainter *p,
 
     const QFont oldFont(p->font());
     QColorGroup mycg(cg);
-    if (color.isValid() && color != KGlobalSettings::textColor())
+    if (color.isValid() && color != KColorScheme(QPalette::Active, KColorScheme::View).foreground().color())
     {
         QFont myFont(oldFont);
         myFont.setBold(true);
         p->setFont(myFont);
-        mycg.setColor(QColorGroup::Text, color);
+        mycg.setColor(QPalette::Text, color);
     }
 
-    QListViewItem::paintCell(p, mycg, col, width, align);
+    Q3ListViewItem::paintCell(p, mycg, col, width, align);
 
     if (color.isValid())
     {
@@ -783,9 +732,9 @@ UpdateDirItem* findOrCreateDirItem(const QString& dirPath,
 
     UpdateDirItem* dirItem(rootItem);
 
-    if (dirPath != QChar('.'))
+    if (dirPath != QLatin1String("."))
     {
-        const QStringList& dirNames(QStringList::split('/', dirPath));
+        const QStringList& dirNames(dirPath.split('/'));
         const QStringList::const_iterator itDirNameEnd(dirNames.end());
         for (QStringList::const_iterator itDirName(dirNames.begin());
              itDirName != itDirNameEnd; ++itDirName)
@@ -800,7 +749,7 @@ UpdateDirItem* findOrCreateDirItem(const QString& dirPath,
                 // - update status (a file item is created for the directory)
                 // - add new directory in Cervisia
                 // - update status
-                kdDebug(8050) << "findOrCreateDirItem(): file changed to dir " << dirName << endl;
+                kDebug(8050) << "file changed to dir " << dirName;
 
                 // just create a new dir item, createDirItem() will delete the
                 // file item and update the m_itemsByName map
@@ -809,7 +758,7 @@ UpdateDirItem* findOrCreateDirItem(const QString& dirPath,
 
             if (!item)
             {
-                kdDebug(8050) << "findOrCreateDirItem(): create dir item " << dirName << endl;
+                kDebug(8050) << "create dir item " << dirName;
                 Entry entry;
                 entry.m_name = dirName;
                 entry.m_type = Entry::Dir;
