@@ -7,7 +7,7 @@
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
-   by the membership of KDE e.V.), which shall act as a proxy 
+   by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.
 
    This program is distributed in the hope that it will be useful,
@@ -23,10 +23,12 @@
 #include <QLayout>
 #include <QHBoxLayout>
 #include <QVBoxLayout>
-#include <QComboBox>
 #include <QSplitter>
 #include <QLabel>
+#include <QTextDocument>
+#include <QTextCursor>
 
+#include <kcombobox.h>
 #include <ktextedit.h>
 #include <kstandardguiitem.h>
 #include <klocale.h>
@@ -102,7 +104,7 @@ MsgInputDialog::MsgInputDialog(MsgInputDialog::MessageType type, const Bug &bug,
     rlabel->setFont( f );
     rlayout->addWidget( rlabel );
 
-    mRecipient = new QComboBox( w );
+    mRecipient = new KComboBox( w );
     mRecipient->insertItem( BugCommand::Normal, i18n("Normal (bugs.kde.org & Maintainer & kde-bugs-dist)") );
     mRecipient->insertItem( BugCommand::Maintonly, i18n("Maintonly (bugs.kde.org & Maintainer)") );
     mRecipient->insertItem( BugCommand::Quiet, i18n("Quiet (bugs.kde.org only)") );
@@ -169,7 +171,7 @@ void MsgInputDialog::updatePresets()
 
   int id = 0;
   QMap<QString,QString>::ConstIterator it;
-  for( it = messageButtons.begin(); it != messageButtons.end(); ++it )
+  for( it = messageButtons.constBegin(); it != messageButtons.constEnd(); ++it )
     mPresets->insertItem( id, it.key() );
 }
 
@@ -234,14 +236,10 @@ void MsgInputDialog::slotCancel()
 
 void MsgInputDialog::insertQuotedMessage( const QString &msg )
 {
-#ifdef __GNUC__
-#warning "kde4: comment before to port it";
-#endif	
-#if 0
-	Q_ASSERT( mMessageEdit->wordWrap() == Q3TextEdit::FixedColumnWidth );
+	Q_ASSERT( mMessageEdit->lineWrapMode() == QTextEdit::FixedColumnWidth );
 
 	const QString quotationMarker = "> ";
-	const int wrapColumn = mMessageEdit->wrapColumnOrWidth();
+	const int wrapColumn = mMessageEdit->lineWrapColumnOrWidth();
 
 	// ### Needs something more sophisticated than simplified to
 	// handle quoting multiple paragraphs properly.
@@ -259,10 +257,10 @@ void MsgInputDialog::insertQuotedMessage( const QString &msg )
 	}
 	quotedMsg += quotationMarker + line + "\n\n";
 
-	mMessageEdit->setPlainText( quotedMsg );
-
-	const int lastPara = mMessageEdit->paragraphs() - 1;
-	const int lastParaLen = mMessageEdit->paragraphLength( lastPara ) - 1;
-	mMessageEdit->setCursorPosition( lastPara, lastParaLen );
-#endif
+    QTextDocument* document = new QTextDocument(mMessageEdit);
+    document->setPlainText( quotedMsg );
+    QTextCursor cursor(document);
+    cursor.movePosition( QTextCursor::End );
+    mMessageEdit->setDocument(document);
+    mMessageEdit->setTextCursor(cursor);
 }
