@@ -35,10 +35,10 @@
 #include <knumvalidator.h>
 
 #include "tracedata.h"
-#include "configuration.h"
+#include "globalconfig.h"
 
 
-ConfigDlg::ConfigDlg(Configuration* c, TraceData* data,
+ConfigDlg::ConfigDlg(GlobalConfig* c, TraceData* data,
                      QWidget* parent)
   :ConfigDlgBase(parent)
 {
@@ -92,9 +92,9 @@ ConfigDlg::ConfigDlg(Configuration* c, TraceData* data,
 
   connect(PushButton2, SIGNAL(clicked()),SLOT(accept()));
   connect(PushButton1, SIGNAL(clicked()),SLOT(reject()));
-  QString objectPrefix = TraceCost::typeName(TraceCost::Object);
-  QString classPrefix = TraceCost::typeName(TraceCost::Class);
-  QString filePrefix = TraceCost::typeName(TraceCost::File);
+  QString objectPrefix = ProfileContext::typeName(ProfileContext::Object);
+  QString classPrefix = ProfileContext::typeName(ProfileContext::Class);
+  QString filePrefix = ProfileContext::typeName(ProfileContext::File);
 
   objectCombo->setDuplicatesEnabled(false);
   classCombo->setDuplicatesEnabled(false);
@@ -106,24 +106,30 @@ ConfigDlg::ConfigDlg(Configuration* c, TraceData* data,
   // first unspecified cost items from data
   TraceObjectMap::Iterator oit;
   QStringList oList;
-  for ( oit = data->objectMap().begin();
-        oit != data->objectMap().end(); ++oit )
-    oList.append((*oit).prettyName());
+  if (data) {
+    for ( oit = data->objectMap().begin();
+          oit != data->objectMap().end(); ++oit )
+      oList.append((*oit).prettyName());
+  }
 
   TraceClassMap::Iterator cit;
   QStringList cList;
-  for ( cit = data->classMap().begin();
-        cit != data->classMap().end(); ++cit )
-    cList.append((*cit).prettyName());
+  if (data) {
+    for ( cit = data->classMap().begin();
+          cit != data->classMap().end(); ++cit )
+      cList.append((*cit).prettyName());
+  }
 
   TraceFileMap::Iterator fit;
   QStringList fList;
-  for ( fit = data->fileMap().begin();
-        fit != data->fileMap().end(); ++fit )
-    fList.append((*fit).prettyName());
+  if (data) {
+    for ( fit = data->fileMap().begin();
+          fit != data->fileMap().end(); ++fit )
+      fList.append((*fit).prettyName());
+  }
 
   // then already defined colors (have to check for duplicates!)
-  Q3DictIterator<Configuration::ColorSetting> it( c->_colors );
+  Q3DictIterator<GlobalConfig::ColorSetting> it( c->_colors );
   for( ; it.current(); ++it ) {
     if ((*it)->automatic) continue;
 
@@ -159,25 +165,27 @@ ConfigDlg::ConfigDlg(Configuration* c, TraceData* data,
 
   Q3ListViewItem* i = new Q3ListViewItem(dirList, i18n("(always)"));
   i->setOpen(true);
-  QStringList::Iterator sit = c->_generalSourceDirs.begin();
-  for(; sit != c->_generalSourceDirs.end(); ++sit ) {
+  QStringList::const_iterator sit = c->_generalSourceDirs.constBegin();
+  for(; sit != c->_generalSourceDirs.constEnd(); ++sit ) {
     QString d = (*sit);
     if (d.isEmpty()) d = "/";
     new Q3ListViewItem(i, d);
   }
-  for ( oit = data->objectMap().begin();
-        oit != data->objectMap().end(); ++oit ) {
-    QString n = (*oit).name();
-    i = new Q3ListViewItem(dirList, n);
-    i->setOpen(true);
-    QStringList* dirs = c->_objectSourceDirs[n];
-    if (!dirs) continue;
+  if (data) {
+    for ( oit = data->objectMap().begin();
+          oit != data->objectMap().end(); ++oit ) {
+      QString n = (*oit).name();
+      i = new Q3ListViewItem(dirList, n);
+      i->setOpen(true);
+      QStringList* dirs = c->_objectSourceDirs[n];
+      if (!dirs) continue;
 
-    sit = dirs->begin();
-    for(; sit != dirs->end(); ++sit ) {
-      QString d = (*sit);
-      if (d.isEmpty()) d = "/";
-      new Q3ListViewItem(i, d);
+      sit = dirs->constBegin();
+      for(; sit != dirs->constEnd(); ++sit ) {
+        QString d = (*sit);
+        if (d.isEmpty()) d = "/";
+        new Q3ListViewItem(i, d);
+      }
     }
   }
 
@@ -199,7 +207,7 @@ ConfigDlg::~ConfigDlg()
 {
 }
 
-bool ConfigDlg::configure(Configuration* c, TraceData* d, QWidget* p)
+bool ConfigDlg::configure(GlobalConfig* c, TraceData* d, QWidget* p)
 {
   ConfigDlg dlg(c, d, p);
 
@@ -231,12 +239,11 @@ void ConfigDlg::objectActivated(const QString & s)
 
   if (s.isEmpty()) { _objectCS=0; return; }
 
-  QString n = TraceCost::typeName(TraceCost::Object) + '-' + s;
+  QString n = ProfileContext::typeName(ProfileContext::Object) + '-' + s;
 
-  Configuration* c = Configuration::config();
-  Configuration::ColorSetting* cs = c->_colors[n];
+  GlobalConfig::ColorSetting* cs = _config->_colors[n];
   if (!cs)
-    cs = Configuration::color(n);
+    cs = GlobalConfig::color(n);
 //  else
 //    qDebug("found color %s", n.ascii());
 
@@ -276,12 +283,11 @@ void ConfigDlg::classActivated(const QString & s)
 
   if (s.isEmpty()) { _classCS=0; return; }
 
-  QString n = TraceCost::typeName(TraceCost::Class) + '-' + s;
+  QString n = ProfileContext::typeName(ProfileContext::Class) + '-' + s;
 
-  Configuration* c = Configuration::config();
-  Configuration::ColorSetting* cs = c->_colors[n];
+  GlobalConfig::ColorSetting* cs = _config->_colors[n];
   if (!cs)
-    cs = Configuration::color(n);
+    cs = GlobalConfig::color(n);
 
   _classCS = cs;
 
@@ -308,12 +314,11 @@ void ConfigDlg::fileActivated(const QString & s)
 
   if (s.isEmpty()) { _fileCS=0; return; }
 
-  QString n = TraceCost::typeName(TraceCost::File) + '-' + s;
+  QString n = ProfileContext::typeName(ProfileContext::File) + '-' + s;
 
-  Configuration* c = Configuration::config();
-  Configuration::ColorSetting* cs = c->_colors[n];
+  GlobalConfig::ColorSetting* cs = _config->_colors[n];
   if (!cs)
-    cs = Configuration::color(n);
+    cs = GlobalConfig::color(n);
 
   _fileCS = cs;
 
@@ -346,17 +351,16 @@ void ConfigDlg::dirsDeletePressed()
   Q3ListViewItem* p = _dirItem->parent();
   if (!p) return;
 
-  Configuration* c = Configuration::config();
   QString objName = p->text(0);
 
   QStringList* dirs;
   if (objName == i18n("(always)"))
-    dirs = &(c->_generalSourceDirs);
+    dirs = &(_config->_generalSourceDirs);
   else
-    dirs = c->_objectSourceDirs[objName];
+    dirs = _config->_objectSourceDirs[objName];
   if (!dirs) return;
 
-  dirs->remove(_dirItem->text(0));
+  dirs->removeAll(_dirItem->text(0));
   delete _dirItem;
   _dirItem = 0;
 
@@ -367,17 +371,16 @@ void ConfigDlg::dirsAddPressed()
 {
   if (!_dirItem || (_dirItem->depth() >0)) return;
 
-  Configuration* c = Configuration::config();
   QString objName = _dirItem->text(0);
 
   QStringList* dirs;
   if (objName == i18n("(always)"))
-    dirs = &(c->_generalSourceDirs);
+    dirs = &(_config->_generalSourceDirs);
   else {
-    dirs = c->_objectSourceDirs[objName];
+    dirs = _config->_objectSourceDirs[objName];
     if (!dirs) {
       dirs = new QStringList;
-      c->_objectSourceDirs.insert(objName, dirs);
+      _config->_objectSourceDirs.insert(objName, dirs);
     }
   }
 
