@@ -18,7 +18,7 @@
 #ifndef NAVVIEWITEM_H
 #define NAVVIEWITEM_H
 
-#include <q3listview.h>
+#include <QTreeWidgetItem>
 
 class NavView;
 
@@ -26,13 +26,15 @@ class NavView;
   *@author Richard Moore
   */
 
-class NavViewItem : public K3ListViewItem  {
+class NavViewItem : public QTreeWidgetItem  {
 public:
   NavViewItem(NavView *parent, QObject *item );
   NavViewItem(NavViewItem *parent, QObject *item );
   ~NavViewItem();
 
   QObject *data;
+private:
+  void init(QObject *obj);
 };
 
 #endif
