@@ -18,18 +18,18 @@
 #ifndef SIGSLOTVIEW_H
 #define SIGSLOTVIEW_H
 
-#include <qwidget.h>
-#include <klistview.h>
+#include <QWidget>
+#include <QTreeWidget>
 
 /**
   *@author Richard Moore
   */
 
-class SigSlotView : public KListView  {
-   Q_OBJECT
+class SigSlotView : public QTreeWidget  {
+  Q_OBJECT
 public: 
-   SigSlotView(QWidget *parent=0, const char *name=0);
-   ~SigSlotView();
+  SigSlotView( QWidget *parent = 0 );
+  ~SigSlotView();
 
   void buildList( QObject *o );
 
