@@ -4,7 +4,7 @@
 
   Copyright (C) 1999-2000   by Matthias Kiefer <matthias.kiefer@gmx.de>
                 2001-2004   by Stanislav Visnovsky <visnovsky@kde.org>
-                2007-2008   by Nick Shaforostoff <shafff@ukr.net>
+                2007-2009   by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -33,38 +33,35 @@
  
 **************************************************************************** */
 
-
-
-
-
-#ifndef DATAMODEL_H
-#define DATAMODEL_H
-
-#include <QUndoStack>
-class QUndoCommand;
-
-#include <kurl.h>
+#ifndef CATALOG_H
+#define CATALOG_H
 
 #include "pos.h"
-#include "catalogitem.h"
-#include "catalogfileplugin.h"
+#include "catalogstring.h"
+#include "catalogcapabilities.h"
+#include "note.h"
+#include "state.h"
+#include "phase.h"
+#include "alttrans.h"
 #include "catalog_private.h"
 class CatalogStorage;
-#include "pluralformtypes_enum.h"
-
-#include "tagrange.h"
-
-#define CHECK_IF_EMPTY(_return_type)\
-if (  d->_entries.isEmpty() )\
-        return _return_type;
-
 
+#include <QUndoStack>
+#include <kurl.h>
 
 namespace GettextCatalog {
   class CatalogImportPlugin;
   class CatalogExportPlugin;
 }
 
+
+bool isApproved(TargetState state, ProjectLocal::PersonRole role);
+TargetState closestState(bool approved, ProjectLocal::PersonRole role);
+int findPrevInList(const QLinkedList<int>& list,int index);
+int findNextInList(const QLinkedList<int>& list,int index);
+void insertInList(QLinkedList<int>& list, int index); // insert index in the right place in the list
+
+
 /**
  * This class represents a catalog
  * It uses CatalogStorage interface to work with catalogs in different formats
@@ -82,8 +79,16 @@ public:
     Catalog(QObject* parent);
     virtual ~Catalog();
 
-    QString msgid(const DocPosition&, const bool noNewlines=false) const;
-    QString msgstr(const DocPosition&, const bool noNewlines=false) const;
+    QString msgid(const DocPosition&) const;
+    virtual QString msgstr(const DocPosition&) const;
+
+    static QStringList supportedExtensions();
+    static bool extIsSupported(const QString& path);
+    static const char* const* states();
+
+    int capabilities() const;
+
+    void push(QUndoCommand* cmd);
 
 public slots: //DBus interface
     QString source(const DocPosition& pos) const {return msgid(pos);}
@@ -91,64 +96,99 @@ public slots: //DBus interface
     // used by XLIFF storage)
     CatalogString sourceWithTags(const DocPosition& pos) const;
     CatalogString targetWithTags(const DocPosition& pos) const;
+    CatalogString catalogString(const DocPosition& pos) const;
 
-    QString comment(uint index) const;
+    /**
+     * @a pos.form is note number
+     * @returns previous note contents, if any
+     */
+    Note setNote(const DocPosition& pos, const Note& note);
+    QVector<Note> notes(const DocPosition& pos) const;
+    QVector<Note> developerNotes(const DocPosition& pos) const;
+    QStringList noteAuthors() const;
+    QVector<AltTrans> altTrans(const DocPosition& pos) const;
+    QStringList sourceFiles(const DocPosition& pos) const;
     QString msgctxt(uint index) const;
+    QString id(const DocPosition& pos) const;
+    ///@returns previous phase-name
+    QString setPhase(const DocPosition& pos, const QString& phase);
+    QString phase(const DocPosition& pos) const;
+    QString activePhase() const{return d->_phase;}
+    ProjectLocal::PersonRole activePhaseRole() const{return d->_phaseRole;}
+    void setActivePhase(const QString& phase, ProjectLocal::PersonRole role=ProjectLocal::Approver);
+    Phase phase(const QString& name) const;
+    QList<Phase> allPhases() const;
+    QMap<QString,Tool> allTools() const;
+    QVector<Note> phaseNotes(const QString& phase) const;
+    ///@arg pos.entry - number of phase, @arg pos.form - number of note
+    QVector<Note> setPhaseNotes(const QString& phase, QVector<Note>);
 
     bool isPlural(uint index) const;
     bool isPlural(const DocPosition& pos) const{return isPlural(pos.entry);}
     bool isApproved(uint index) const;
     bool isApproved(const DocPosition& pos) const{return isApproved(pos.entry);}
-    bool isUntranslated(uint index) const; //at least one form is untranslated
-    bool isUntranslated(const DocPosition&) const;
-    bool isModified(int entry);
+    TargetState state(const DocPosition& pos) const;
+    bool isEquivTrans(const DocPosition&) const;
+    ///@returns true if at least one form is untranslated
+    bool isEmpty(uint index) const;
+    bool isEmpty(const DocPosition&) const;
+    bool isModified(DocPos entry) const;
+    bool isModified(int entry) const;
+
+    /// so DocPosition::entry may actually be < size()+binUnitsCount()
+    int binUnitsCount() const;
+
+    int unitById(const QString& id) const;
+
+    bool isBookmarked(uint index) const{return d->_bookmarkIndex.contains(index);}
+    void setBookmark(uint, bool);
 
     int numberOfPluralForms() const {return d->_numberOfPluralForms;}
     int numberOfEntries() const;
-    int numberOfNonApproved() const {return d->_fuzzyIndex.size();}
-    int numberOfUntranslated() const {return d->_untransIndex.size();}
+    int numberOfNonApproved() const {return d->_nonApprovedIndex.size();}
+    int numberOfUntranslated() const {return d->_emptyIndex.size();}
+
 
 public:
-    int firstFuzzyIndex() const {return d->_fuzzyIndex.isEmpty()?numberOfEntries():d->_fuzzyIndex.first();}
-    int lastFuzzyIndex() const {return d->_fuzzyIndex.isEmpty()?-1:d->_fuzzyIndex.last();}
-    int nextFuzzyIndex(uint index) const {return findNextInList(d->_fuzzyIndex,index);}
-    int prevFuzzyIndex(uint index) const {return findPrevInList(d->_fuzzyIndex,index);}
-    int firstUntranslatedIndex() const {return d->_untransIndex.isEmpty()?numberOfEntries():d->_untransIndex.first();}
-    int lastUntranslatedIndex() const {return d->_untransIndex.isEmpty()?-1:d->_untransIndex.last();}
-    int nextUntranslatedIndex(uint index) const {return findNextInList(d->_untransIndex,index);}
-    int prevUntranslatedIndex(uint index) const {return findPrevInList(d->_untransIndex,index);}
+    int firstFuzzyIndex() const {return d->_nonApprovedIndex.isEmpty()?numberOfEntries():d->_nonApprovedIndex.first();}
+    int lastFuzzyIndex() const {return d->_nonApprovedIndex.isEmpty()?-1:d->_nonApprovedIndex.last();}
+    int nextFuzzyIndex(uint index) const {return findNextInList(d->_nonApprovedIndex,index);}
+    int prevFuzzyIndex(uint index) const {return findPrevInList(d->_nonApprovedIndex,index);}
+    int firstUntranslatedIndex() const {return d->_emptyIndex.isEmpty()?numberOfEntries():d->_emptyIndex.first();}
+    int lastUntranslatedIndex() const {return d->_emptyIndex.isEmpty()?-1:d->_emptyIndex.last();}
+    int nextUntranslatedIndex(uint index) const {return findNextInList(d->_emptyIndex,index);}
+    int prevUntranslatedIndex(uint index) const {return findPrevInList(d->_emptyIndex,index);}
 
     int firstBookmarkIndex() const {return d->_bookmarkIndex.isEmpty()?numberOfEntries():d->_bookmarkIndex.first();}
     int lastBookmarkIndex() const {return d->_bookmarkIndex.isEmpty()?-1:d->_bookmarkIndex.last();}
     int nextBookmarkIndex(uint index) const {return findNextInList(d->_bookmarkIndex,index);}
     int prevBookmarkIndex(uint index) const {return findPrevInList(d->_bookmarkIndex,index);}
 
-public slots: //DBus interface
-    bool isBookmarked(uint index) const{return d->_bookmarkIndex.contains(index);}
-    void setBookmark(uint,bool);
-
+    bool autoSaveRecovered(){return d->_autoSaveRecovered;}
 public:
-    void setPackageName( QString s ){d->_packageName = s;}
-
     void clear();
     bool isEmpty(){return !m_storage;}
+    bool isReadOnly(){return d->_readOnly;}
 
-    void setErrorIndex(const QList<int>& errors){d->_errorIndex=errors;}
+    void attachAltTransCatalog(Catalog*);
 
+
+    virtual const DocPosition& undo();
+    virtual const DocPosition& redo();
+
+    //void setErrorIndex(const QList<int>& errors){d->_errorIndex=errors;}
     void setUrl(const KUrl& u){d->_url=u;}//used for template load
 public slots: //DBus interface
     const KUrl& url() const {return d->_url;}
-    bool loadFromUrl(const KUrl& url);
+    ///@returns 0 if success, >0 erroneous line (parsing error)
+    int loadFromUrl(const KUrl& url, const KUrl& saidUrl=KUrl(), int* fileSize=0);
     bool saveToUrl(KUrl url);
     bool save();
-
+    QByteArray contents();
     QString mimetype();
 
-public:
-    virtual const DocPosition& undo();
-    virtual const DocPosition& redo();
-    virtual void push(QUndoCommand *cmd/*,bool rebaseForDBUpdate=false*/);
-
+protected:
+    virtual KAutoSaveFile* checkAutoSave(const KUrl& url);
 
 protected slots:
     /**
@@ -156,6 +196,9 @@ protected slots:
      */
     void flushUpdateDBBuffer();
 
+    void doAutoSave();
+    void setAutoSaveDirty(){d->_autoSaveDirty=true;}
+
 protected:
     /**
      * (EDITING)
@@ -173,42 +216,43 @@ protected:
     void setApproved(const DocPosition& pos, bool approved);
     void targetDelete(const DocPosition& pos, int count);
     void targetInsert(const DocPosition& pos, const QString& arg);
+    InlineTag targetDeleteTag(const DocPosition& pos);
+    void targetInsertTag(const DocPosition& pos, const InlineTag& tag);
+    TargetState setState(const DocPosition& pos, TargetState state);
+    Phase updatePhase(const Phase& phase);
+    void setEquivTrans(const DocPosition&, bool equivTrans);
 
-    /**
-     * @returns true if entry wasn't modified before
-     */
-    bool setModified(int entry,bool modif);
+    /// @returns true if entry wasn't modified before
+    bool setModified(DocPos entry, bool modif);
 
-protected:
-    int findPrevInList(const QList<int>& list,int index) const;
-    int findNextInList(const QList<int>& list,int index) const;
-
-//private:
 protected:
     CatalogPrivate *d;
     CatalogStorage *m_storage;
 
     friend class GettextCatalog::CatalogImportPlugin;
     friend class GettextCatalog::CatalogExportPlugin;
+    friend class LokalizeUnitCmd;
     friend class InsTextCmd;
     friend class DelTextCmd;
-    friend class ToggleFuzzyCmd;
-    friend class ToggleApprovementCmd;
+    friend class InsTagCmd;
+    friend class DelTagCmd;
+    friend class SetStateCmd;
+    friend class SetNoteCmd;
+    friend class UpdatePhaseCmd;
     friend class MergeCatalog;
+    friend class SetEquivTransCmd;
 
 signals:
-    void signalEntryChanged(const DocPosition&);
+    void signalEntryModified(const DocPosition&);
+    void activePhaseChanged();
     void signalNumberOfFuzziesChanged();
-    void signalNumberOfUntranslatedChanged();
+    void signalNumberOfEmptyChanged();
     Q_SCRIPTABLE void signalFileLoaded();
     void signalFileLoaded(const KUrl&);
     Q_SCRIPTABLE void signalFileSaved();
     void signalFileSaved(const KUrl&);
-
-    //void signalCmdPushed(QUndoCommand *cmd);//for merging (on-the-fly changes replication)
-
-
 };
 
+
 #endif
 
