@@ -1,24 +1,25 @@
-/*
-This file is part of Lokalize
+/* ****************************************************************************
+  This file is part of Lokalize
 
-Copyright 2008 Nick Shaforostoff <shaforostoff@kde.ru>
+  Copyright (C) 2008-2009 by Nick Shaforostoff <shafff@ukr.net>
 
-This program is free software; you can redistribute it and/or
-modify it under the terms of the GNU General Public License as
-published by the Free Software Foundation; either version 2 of
-the License or (at your option) version 3 or any later version
-accepted by the membership of KDE e.V. (or its successor approved
-by the membership of KDE e.V.), which shall act as a proxy 
-defined in Section 14 of version 3 of the license.
+  This program is free software; you can redistribute it and/or
+  modify it under the terms of the GNU General Public License as
+  published by the Free Software Foundation; either version 2 of
+  the License or (at your option) version 3 or any later version
+  accepted by the membership of KDE e.V. (or its successor approved
+  by the membership of KDE e.V.), which shall act as a proxy 
+  defined in Section 14 of version 3 of the license.
 
-This program is distributed in the hope that it will be useful,
-but WITHOUT ANY WARRANTY; without even the implied warranty of
-MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+  This program is distributed in the hope that it will be useful,
+  but WITHOUT ANY WARRANTY; without even the implied warranty of
+  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+  GNU General Public License for more details.
 
-You should have received a copy of the GNU General Public License
-along with this program.  If not, see <http://www.gnu.org/licenses/>.
-*/
+  You should have received a copy of the GNU General Public License
+  along with this program.  If not, see <http://www.gnu.org/licenses/>.
+
+**************************************************************************** */
 
 #include "gettextheader.h"
 
@@ -39,53 +40,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <kio/netaccess.h>
 #include <ktemporaryfile.h>
 
-#if 0
-pInfo.insert("cs", "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
-pInfo.insert("da", "nplurals=2; plural=(n != 1);");
-pInfo.insert("de", "nplurals=2; plural=n != 1;");
-pInfo.insert("el", "nplurals=2; plural=(n != 1);");
-pInfo.insert("en", "nplurals=2; plural=(n != 1);");
-pInfo.insert("en_GB", "nplurals=2; plural=(n != 1);");
-pInfo.insert("en_US", "nplurals=2; plural=(n != 1);");
-pInfo.insert("eo", "nplurals=2; plural=(n != 1);");
-pInfo.insert("es", "nplurals=2; plural=(n != 1);");
-pInfo.insert("et", "nplurals=2; plural=(n != 1);");
-pInfo.insert("fi", "nplurals=2; plural=(n != 1);");
-pInfo.insert("fo", "nplurals=2; plural=(n != 1);");
-pInfo.insert("fr", "nplurals=2; plural=(n > 1);");
-pInfo.insert("ga", "nplurals=3; plural=n==1 ? 0 : n==2 ? 1 : 2;");
-pInfo.insert("he", "nplurals=2; plural=(n != 1);");
-pInfo.insert("hr", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
-pInfo.insert("hu", "nplurals=2; plural=(n != 1);");
-pInfo.insert("it", "nplurals=2; plural=(n != 1);");
-pInfo.insert("ja", "nplurals=1; plural=0;");
-pInfo.insert("ko", "nplurals=1; plural=0;");
-pInfo.insert("lt", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
-pInfo.insert("lv", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
-pInfo.insert("nb", "nplurals=2; plural=(n != 1);");
-pInfo.insert("nl", "nplurals=2; plural=(n != 1);");
-pInfo.insert("nn", "nplurals=2; plural=(n != 1);");
-pInfo.insert("pl", "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
-pInfo.insert("pt", "nplurals=2; plural=(n != 1);");
-pInfo.insert("pt_BR", "nplurals=2; plural=(n > 1);");
-pInfo.insert("ro", "nplurals=3; plural=n==1 ? 0 : (n==0 || (n%100 > 0 && n%100 < 20)) ? 1 : 2;");
-pInfo.insert("ru", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
-pInfo.insert("sk", "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
-pInfo.insert("sl", "nplurals=4; plural=(n%100==1 ? 1 : n%100==2 ? 2 : n%100==3 || n%100==4 ? 3 : 0);");
-pInfo.insert("sr", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
-pInfo.insert("sr@latin", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
-pInfo.insert("sv", "nplurals=2; plural=(n != 1);");
-pInfo.insert("tr", "nplurals=1; plural=0;");
-pInfo.insert("uk", "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
-pInfo.insert("vi", "nplurals=1; plural=0;");
-#endif
-
 /**
  * this data was obtained by running GNUPluralForms()
  * on all languages KDE knows of
 **/
-#define NUM_LANG_WITH_INFO 38
+#define NUM_LANG_WITH_INFO 39
 static const char* langsWithPInfo[NUM_LANG_WITH_INFO]={
+"ar",
 "cs",
 "da",
 "de",
@@ -128,6 +89,7 @@ static const char* langsWithPInfo[NUM_LANG_WITH_INFO]={
 };
 
 static const char* pInfo[NUM_LANG_WITH_INFO]={
+"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;",
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;",
 "nplurals=2; plural=(n != 1);",
 "nplurals=2; plural=n != 1;",
@@ -150,9 +112,9 @@ static const char* pInfo[NUM_LANG_WITH_INFO]={
 "nplurals=1; plural=0;",
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);",
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);",
+"nplurals=2; plural=n != 1;",
 "nplurals=2; plural=(n != 1);",
-"nplurals=2; plural=(n != 1);",
-"nplurals=2; plural=(n != 1);",
+"nplurals=2; plural=n != 1;",
 "nplurals=3; plural=(n==1 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);",
 "nplurals=2; plural=(n != 1);",
 "nplurals=2; plural=(n > 1);",
@@ -197,11 +159,8 @@ QString GNUPluralForms(const QString& lang)
 {
     QByteArray l(lang.toUtf8());
     int i=NUM_LANG_WITH_INFO;
-    while(--i>=0)
-    {
-        if (l==langsWithPInfo[i])
-            break;
-    }
+    while(--i>=0 && l!=langsWithPInfo[i])
+        ;
     //if (KDE_ISLIKELY( langsWithPInfo[i]))
     if (KDE_ISLIKELY( i>=0 ))
         return QString::fromLatin1(pInfo[i]);
@@ -223,7 +182,7 @@ QString GNUPluralForms(const QString& lang)
     msginit.waitForStarted(5000);
     if (KDE_ISUNLIKELY( msginit.state()!=QProcess::Running ))
     {
-        kWarning()<<"msginit error";
+        //kWarning()<<"msginit error";
         return def;
     }
 
@@ -258,7 +217,7 @@ QString GNUPluralForms(const QString& lang)
     int pos = result.indexOf("Plural-Forms: ");
     if (KDE_ISUNLIKELY( pos==-1 ))
     {
-        kWarning()<<"msginit error"<<result;
+        //kWarning()<<"msginit error"<<result;
         return def;
     }
     pos+=14;
@@ -266,7 +225,7 @@ QString GNUPluralForms(const QString& lang)
     int end = result.indexOf('"',pos);
     if (KDE_ISUNLIKELY( pos==-1 ))
     {
-        kWarning()<<"msginit error"<<result;
+        //kWarning()<<"msginit error"<<result;
         return def;
     }
 
@@ -290,83 +249,65 @@ void updateHeader(QString& header,
     QStringList::Iterator it,ait;
     QString temp;
 
-
     bool found=false;
-
     temp="Last-Translator: "+Settings::authorName();
     if (!Settings::authorEmail().isEmpty())
         temp+=(" <"+Settings::authorEmail()+'>');
     temp+="\\n";
 
-
-    for ( it = headerList.begin(); it != headerList.end(); ++it )
+    for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
         if (it->contains(QRegExp("^ *Last-Translator:.*")))
         {
-            if (forSaving)
-                (*it) = temp;
+            if (forSaving) *it = temp;
             found=true;
         }
     }
-
     if (KDE_ISUNLIKELY( !found ))
         headerList.append(temp);
 
     QString dateTimeString = KDateTime::currentLocalDateTime().toString("%Y-%m-%d %H:%M%z");
-    found=false;
     temp="PO-Revision-Date: "+dateTimeString+"\\n";
-
-    for ( it = headerList.begin(); it != headerList.end(); ++it )
+    for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
-        if (it->contains(QRegExp("^ *PO-Revision-Date:.*")))
-        {
-            if (forSaving)
-                (*it) = temp;
-            found=true;
-        }
+        found=it->contains(QRegExp("^ *PO-Revision-Date:.*"));
+        if (found && forSaving) *it = temp;
     }
     if (KDE_ISUNLIKELY( !found ))
         headerList.append(temp);
 
-    found=false;
-
     temp="Project-Id-Version: "+CatalogProjectId+"\\n";
     temp.remove(".pot");
     temp.remove(".po");
     //temp.replace( "@PACKAGE@", packageName());
 
-    for ( it = headerList.begin(); it != headerList.end(); ++it )
+    for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
-        if (it->contains(QRegExp("^ *Project-Id-Version:.*")))
-        {
-            if (it->contains("PACKAGE VERSION"))
-                (*it) = temp;
-            found=true;
-        }
+        found=it->contains(QRegExp("^ *Project-Id-Version:.*"));
+        if (found && it->contains("PACKAGE VERSION"))
+            *it = temp;
     }
     if (KDE_ISUNLIKELY( !found ))
         headerList.append(temp);
 
-    found=false;
     langCode=Project::instance()->isLoaded()?
              Project::instance()->langCode():
              Settings::defaultLangCode();
 
     KConfig lll("all_languages", KConfig::NoGlobals, "locale");
     lll.setLocale("");
-    for ( it = headerList.begin(); it != headerList.end(); ++it )
+    for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
     {
-        if (it->contains(QRegExp("^ *Language-Team:.*")))
+        found=it->contains(QRegExp("^ *Language-Team:.*"));
+        if (found)
         {
-            found=true;
             //really parse header
             QMap<QString,QString> map;
             QStringList langlist = KGlobal::locale()->languageList();
-            QStringList::const_iterator myit;
-            for (myit=langlist.begin();myit!=langlist.end();++myit)
+            foreach (const QString &myit, langlist)
             {
-                KConfigGroup cg(&lll, *myit);
-                map[cg.readEntry("Name")]=*myit;
+                KConfigGroup cg(&lll, myit);
+                map[cg.readEntry("Name")]=myit;
             }
 
             QRegExp re("^ *Language-Team: *(.*) *<");
@@ -377,6 +318,7 @@ void updateHeader(QString& header,
             ait=it;
         }
     }
+
     //language=locale.languageCodeToName(d->_langCode);
     KConfigGroup cg(&lll, langCode);
     QString language=cg.readEntry("Name");
@@ -388,8 +330,6 @@ void updateHeader(QString& header,
         temp+=" <"+Project::instance()->mailingList()+'>';
     else
         temp+=" <"+Settings::defaultMailingList()+'>';
-/*    if (!identityOptions->readEntry("DefaultMailingList").isEmpty())
-        temp+=(" <"+identityOptions->readEntry("DefaultMailingList")+'>');*/
     temp+="\\n";
 
     if (KDE_ISLIKELY( found ))
@@ -398,115 +338,55 @@ void updateHeader(QString& header,
         headerList.append(temp);
 
 
-//     if(!usePrefs || saveOptions.updateCharset)
-//     {
-//         found=false;
-//
-//         QString encodingStr;
-//         if(saveOptions.useOldEncoding && d->fileCodec)
-//         {
-//             encodingStr = charsetString(d->fileCodec);
-//         }
-//         else
-//         {
-//             encodingStr=charsetString(saveOptions.encoding);
-//         }
-//         it = headerList.begin();
-//         while( it != headerList.end() )
-//         {
-//             if( it->contains( QRegExp( "^ *Content-Type:.*" ) ) )
-//             {
-//                 if ( found )
-//                 {
-//                     // We had already a Content-Type, so we do not need a duplicate
-//                     it = headerList.erase( it );
-//                 }
-//                 else
-//                 {
-//                     found=true;
-//                     QRegExp regexp( "^ *Content-Type:(.*/.*);?\\s*charset=.*$" );
-//                     QString mimeType;
-//                     if ( regexp.indexIn( *it )!=-1 )
-//                     {
-//                         mimeType = regexp.cap( 1 ).trimmed();
-//                     }
-//                     if ( mimeType.isEmpty() )
-//                     {
-//                         mimeType = "text/plain";
-//                     }
-//                     temp = "Content-Type: ";
-//                     temp += mimeType;
-//                     temp += "; charset=";
-//                     temp += encodingStr;
-//                     temp += "\\n";
-//                     (*it) = temp;
-//                 }
-//             }
-//             ++it;
-//         }
-//         if(!found)
-//         {
-//             headerList.append(temp);
-//         }
-//     }
+    temp="Content-Type: text/plain; charset=UTF-8\\n";
+    for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
+    {
+        found=it->contains(QRegExp("^ *Content-Type:.*"));
+        if (found) *it=temp;
+    }
+    if (KDE_ISUNLIKELY( !found ))
+        headerList.append(temp);
+
+
     found=false;
     temp="Content-Transfer-Encoding: 8bit\\n";
 
-    for ( it = headerList.begin(); it != headerList.end(); ++it )
-    {
-        if (it->contains(QRegExp("^ *Content-Transfer-Encoding:.*")))
-            found=true;
-    }
+    for ( it = headerList.begin(),found=false; it != headerList.end() && !found; ++it )
+        found=it->contains(QRegExp("^ *Content-Transfer-Encoding:.*"));
     if (!found)
         headerList.append(temp);
 
     temp="X-Generator: Lokalize %1\\n";
-    temp=temp.arg(KAIDER_VERSION);
-    found=false;
+    temp=temp.arg(LOKALIZE_VERSION);
 
-    for ( it = headerList.begin(); it != headerList.end(); ++it )
+    for ( it = headerList.begin(),found=false; it != headerList.end()&& !found; ++it )
     {
-        if (it->contains(QRegExp("^ *X-Generator:.*")))
-        {
-            (*it) = temp;
-            found=true;
-        }
+        found=it->contains(QRegExp("^ *X-Generator:.*"));
+        if (found) *it = temp;
     }
     if (KDE_ISUNLIKELY( !found ))
         headerList.append(temp);
 
     // ensure MIME-Version header
     temp="MIME-Version: 1.0\\n";
-    found=false;
-    for ( it = headerList.begin(); it != headerList.end(); ++it )
+    for ( it = headerList.begin(),found=false; it != headerList.end()&& !found; ++it )
     {
-        if (it->contains(QRegExp("^ *MIME-Version:")))
-        {
-            (*it) = temp;
-            found=true;
-        }
+        found=it->contains(QRegExp("^ *MIME-Version:"));
+        if (found) *it = temp;
     }
     if (KDE_ISUNLIKELY( !found ))
-    {
         headerList.append(temp);
-    }
 
 
-    found=false;
-
     kDebug()<<"testing for GNUPluralForms";
     // update plural form header
-    for ( it = headerList.begin(); it != headerList.end(); ++it )
-    {
-        if (it->contains(QRegExp("^ *Plural-Forms:")))
-        {
-            found=true;
-            break;
-        }
-    }
+    for ( it = headerList.begin(),found=false; it != headerList.end()&& !found; ++it )
+        found=it->contains(QRegExp("^ *Plural-Forms:"));
     if (found)
     {
-        kDebug()<<"GNUPluralForms found";
+        --it;
+
+        //kDebug()<<"GNUPluralForms found";
         int num=numberOfPluralFormsFromHeader(header);
         if (!num)
         {
@@ -516,7 +396,7 @@ void updateHeader(QString& header,
             {
                 kWarning()<<"No plural form info in header, using project-defined one"<<langCode;
                 QString t=GNUPluralForms(langCode);
-                kWarning()<<"generated: " << t;
+                //kWarning()<<"generated: " << t;
                 if ( !t.isEmpty() )
                 {
                     QRegExp pf("^ *Plural-Forms:\\s*nplurals.*\\\\n");
@@ -532,46 +412,32 @@ void updateHeader(QString& header,
                 }
             }
         }
-        //setNumberOfPluralForms(num);
         numberOfPluralForms=num;
 
     }
     else if ( !generatedFromDocbook)
     {
-        kDebug()<<"generating GNUPluralForms"<<langCode;
+        //kDebug()<<"generating GNUPluralForms"<<langCode;
         QString t= GNUPluralForms(langCode);
-        kDebug()<<"here it is:";
+        //kDebug()<<"here it is:";
         if ( !t.isEmpty() )
             headerList.append(QString("Plural-Forms: %1\\n").arg(t));
     }
 
     //m_header.setMsgstr( headerList.join( "\n" ) );
     header=headerList.join("\n");
-
 //END header itself
 
 //BEGIN comment = description, copyrights
-    found=false;
-
-    for ( it = commentList.begin(); it != commentList.end(); ++it )
+    // U+00A9 is the Copyright sign
+    QRegExp fsfc("^# *Copyright (\\(C\\)|\\x00a9).*Free Software Foundation, Inc");
+    for ( it = commentList.begin(),found=false; it != commentList.end()&&!found; ++it )
     {
-        // U+00A9 is the Copyright sign
-        if ( it->contains( QRegExp("^# *Copyright (\\(C\\)|\\x00a9).*Free Software Foundation, Inc") ) )
-        {
-            found=true;
-            break;
-        }
+        found=it->contains( fsfc ) ;
+        if (found)
+            it->replace("YEAR", QDate::currentDate().toString("yyyy"));
     }
-    if (found)
-    {
-        if ( it->contains( QRegExp("^# *Copyright (\\(C\\)|\\x00a9) YEAR Free Software Foundation, Inc\\.") ) )
-        {
-            //template string
-//     		if( saveOptions.FSFCopyright == ProjectSettingsBase::Remove)
-            it->remove(" YEAR Free Software Foundation, Inc");
-            /*		else
-            		    it->replace("YEAR", QDate::currentDate().toString("yyyy"));*/
-        } /*else
+/*
                         	    if( saveOptions.FSFCopyright == ProjectSettingsBase::Update )
                         	    {
                         		    //update years
@@ -588,7 +454,6 @@ void updateHeader(QString& header,
                         			}
                         		    }
                         	    }*/
-    }
 #if 0
     if ( ( !usePrefs || saveOptions.updateDescription )
             && ( !saveOptions.descriptionString.isEmpty() ) )
