@@ -1,33 +1,36 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2005-2008                                                *
- *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
+ *   copyright (C) 2005-2008                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "idlimport.h"
 
-#include <stdio.h>
-// qt/kde includes
-// #include <qprocess.h>  //should use this instead of popen()
+// app includes
+#include "attribute.h"
+#include "classifier.h"
+#include "enum.h"
+#include "import_utils.h"
+#include "operation.h"
+#include "package.h"
+#include "uml.h"
+#include "umldoc.h"
+#include "umlpackagelist.h"
+
+// kde includes
+#include <kdebug.h>
+
+// qt includes
+// #include <QtCore/QProcess>  //should use this instead of popen()
 #include <QtCore/QStringList>
 #include <QtCore/QRegExp>
-#include <kdebug.h>
-// app includes
-#include "import_utils.h"
-#include "../uml.h"
-#include "../umldoc.h"
-#include "../umlpackagelist.h"
-#include "../package.h"
-#include "../classifier.h"
-#include "../enum.h"
-#include "../operation.h"
-#include "../attribute.h"
+
+#include <stdio.h>
 
 IDLImport::IDLImport() : NativeImportBase("//")
 {
@@ -51,19 +54,29 @@ QString IDLImport::joinTypename()
     return typeName;
 }
 
+/**
+ * Override operation from NativeImportBase.
+ */
 bool IDLImport::preprocess(QString& line)
 {
     // Ignore C preprocessor generated lines.
     if (line.startsWith('#'))
         return true;  // done
+
+/**
+ * Override operation from NativeImportBase.
+ */
     return NativeImportBase::preprocess(line);
 }
 
+/**
+ * Implement abstract operation from NativeImportBase.
+ */
 void IDLImport::fillSource(const QString& word)
 {
     QString lexeme;
     const uint len = word.length();
-    for (uint i = 0; i < len; i++) {
+    for (uint i = 0; i < len; ++i) {
         QChar c = word[i];
         if (c.isLetterOrNumber() || c == '_') {
             lexeme += c;
@@ -79,7 +92,7 @@ void IDLImport::fillSource(const QString& word)
         } else {
             if (!lexeme.isEmpty()) {
                 m_source.append(lexeme);
-                lexeme = QString();
+                lexeme.clear();
             }
             m_source.append(QString(c));
         }
@@ -88,6 +101,10 @@ void IDLImport::fillSource(const QString& word)
         m_source.append(lexeme);
 }
 
+/**
+ * Reimplement operation from NativeImportBase.
+ * Need to do this because we use the external C preprocessor.
+ */
 void IDLImport::parseFile(const QString& filename)
 {
     if (filename.contains('/')) {
@@ -96,10 +113,10 @@ void IDLImport::parseFile(const QString& filename)
         uDebug() << "adding path " << path;
         Import_Utils::addIncludePath(path);
     }
-    QStringList includePaths = Import_Utils::includePathList();
+    const QStringList includePaths = Import_Utils::includePathList();
     //QProcess command("cpp", UMLAp::app());
     QString command("cpp -C");   // -C means "preserve comments"
-    for (QStringList::Iterator pathIt = includePaths.begin();
+    for (QStringList::ConstIterator pathIt = includePaths.begin();
             pathIt != includePaths.end(); ++pathIt) {
         QString path = (*pathIt);
         //command.addArgument(" -I" + path);
@@ -125,7 +142,7 @@ void IDLImport::parseFile(const QString& filename)
     m_scopeIndex = 0;
     m_scope[0] = NULL;
     const int srcLength = m_source.count();
-    for (m_srcIndex = 0; m_srcIndex < srcLength; m_srcIndex++) {
+    for (m_srcIndex = 0; m_srcIndex < srcLength; ++m_srcIndex) {
         const QString& keyword = m_source[m_srcIndex];
         //uDebug() << '"' << keyword << '"';
         if (keyword.startsWith(m_singleLineCommentIntro)) {
@@ -135,11 +152,14 @@ void IDLImport::parseFile(const QString& filename)
         if (! parseStmt())
             skipStmt();
         m_currentAccess = Uml::Visibility::Public;
-        m_comment = QString();
+        m_comment.clear();
     }
     pclose(fp);
 }
 
+/**
+ * Implement abstract operation from NativeImportBase.
+ */
 bool IDLImport::parseStmt()
 {
     const QString& keyword = m_source[m_srcIndex];
@@ -164,7 +184,7 @@ bool IDLImport::parseStmt()
         m_klass->setStereotype("CORBAInterface");
         m_klass->setAbstract(m_isAbstract);
         m_isAbstract = false;
-        m_comment = QString();
+        m_comment.clear();
         if (advance() == ";")   // forward declaration
             return true;
         if (m_source[m_srcIndex] == ":") {
@@ -176,8 +196,7 @@ bool IDLImport::parseStmt()
             }
         }
         if (m_source[m_srcIndex] != "{") {
-            uError() << "importIDL: ignoring excess chars at "
-            << name;
+            uError() << "importIDL: ignoring excess chars at " << name;
             skipStmt("{");
         }
         return true;
