@@ -1,24 +1,16 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *  copyright (C) 2004-2008                                                *
- *  Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                   *
+ *   copyright (C) 2004-2009                                               *
+ *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
 // own header
 #include "model_utils.h"
 
-// qt/kde includes
-#include <QtCore/QRegExp>
-#include <QtCore/QStringList>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kinputdialog.h>
-
 // app includes
 #include "umlobject.h"
 #include "umlpackagelist.h"
@@ -37,8 +29,22 @@
 #include "uml.h"
 #include "codegenerator.h"
 
+// kde includes
+#include <klocale.h>
+#include <kdebug.h>
+
+// qt includes
+#include <QtCore/QRegExp>
+#include <QtCore/QStringList>
+
 namespace Model_Utils {
 
+/**
+ * Determines whether the given widget type is cloneable.
+ *
+ * @param type  The input Widget_Type.
+ * @return      True if the given type is cloneable.
+ */
 bool isCloneable(Uml::Widget_Type type)
 {
     switch (type) {
@@ -58,7 +64,16 @@ bool isCloneable(Uml::Widget_Type type)
     }
 }
 
-UMLObject * findObjectInList(Uml::IDType id, const UMLObjectList& inList)
+/**
+ * Seek the given id in the given list of objects.
+ * Each list element may itself contain other objects
+ * and the search is done recursively.
+ *
+ * @param id       The unique ID to seek.
+ * @param inList   The UMLObjectList in which to search.
+ * @return Pointer to the UMLObject that matches the ID (NULL if none matches).
+ */
+UMLObject* findObjectInList(Uml::IDType id, const UMLObjectList& inList)
 {
     for (UMLObjectListIt oit(inList); oit.hasNext(); ) {
         UMLObject *obj = oit.next();
@@ -103,6 +118,20 @@ UMLObject * findObjectInList(Uml::IDType id, const UMLObjectList& inList)
     return NULL;
 }
 
+/**
+ * Find the UML object of the given type and name in the passed-in list.
+ *
+ * @param inList        List in which to seek the object.
+ * @param name          Name of the object to find.
+ * @param type          Object_Type of the object to find (optional.)
+ *                      When the given type is ot_UMLObject the type is
+ *                      disregarded, i.e. the given name is the only
+ *                      search criterion.
+ * @param currentObj    Object relative to which to search (optional.)
+ *                      If given then the enclosing scope(s) of this
+ *                      object are searched before the global scope.
+ * @return      Pointer to the UMLObject found, or NULL if not found.
+ */
 UMLObject* findUMLObject(const UMLObjectList& inList,
                          const QString& inName,
                          Uml::Object_Type type /* = ot_UMLObject */,
@@ -239,6 +268,16 @@ UMLObject* findUMLObject(const UMLObjectList& inList,
     return NULL;
 }
 
+/**
+ * Returns a name for the new object, appended with a number
+ * if the default name is taken e.g. new_actor, new_actor_1
+ * etc.
+ * @param type      The object type.
+ * @param parentPkg The package in which to compare the name.
+ * @param prefix    The prefix to use (optional)
+ *                  If no prefix is given then a type related
+ *                  prefix will be chosen internally.
+ */
 QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString prefix)
 {
     QString currentName = prefix;
@@ -278,12 +317,18 @@ QString uniqObjectName(Uml::Object_Type type, UMLPackage *parentPkg, QString pre
     }
     UMLDoc *doc = UMLApp::app()->getDocument();
     QString name = currentName;
-    for (int number = 1; !doc->isUnique(name, parentPkg); number++)  {
+    for (int number = 1; !doc->isUnique(name, parentPkg); ++number)  {
         name = currentName + '_' + QString::number(number);
     }
     return name;
 }
 
+/**
+ * Return true if the given tag is a one of the common XMI
+ * attributes, such as:
+ * "name" | "visibility" | "isRoot" | "isLeaf" | "isAbstract" |
+ * "isActive" | "ownerScope"
+ */
 bool isCommonXMIAttribute( const QString &tag )
 {
     bool retval = (Uml::tagEq(tag, "name") ||
@@ -304,15 +349,20 @@ bool isCommonXMIAttribute( const QString &tag )
     return retval;
 }
 
+/**
+ * Return true if the given type is common among the majority
+ * of programming languages, such as "bool" or "boolean".
+ * TODO: Make this depend on the active programming language.
+ */
 bool isCommonDataType(QString type)
 {
     CodeGenerator *gen = UMLApp::app()->getGenerator();
     if (gen == NULL)
         return false;
     const bool caseSensitive = UMLApp::app()->activeLanguageIsCaseSensitive();
-    QStringList dataTypes = gen->defaultDatatypes();
-    QStringList::Iterator end(dataTypes.end());
-    for (QStringList::Iterator it = dataTypes.begin(); it != end; ++it) {
+    const QStringList dataTypes = gen->defaultDatatypes();
+    QStringList::ConstIterator end(dataTypes.end());
+    for (QStringList::ConstIterator it = dataTypes.begin(); it != end; ++it) {
         if (caseSensitive) {
             if (type == *it)
                 return true;
@@ -323,6 +373,9 @@ bool isCommonDataType(QString type)
     return false;
 }
 
+/**
+ * Return true if the given object type is a classifier list item type.
+ */
 bool isClassifierListitem(Uml::Object_Type type)
 {
     if (type == Uml::ot_Attribute ||
@@ -339,6 +392,12 @@ bool isClassifierListitem(Uml::Object_Type type)
     }
 }
 
+/**
+ * Try to guess the correct container folder type of an UMLObject.
+ * Object types that can't be guessed are mapped to Uml::mt_Logical.
+ * NOTE: This function exists mainly for handling pre-1.5.5 files
+ *       and should not be used for new code.
+ */
 Uml::Model_Type guessContainer(UMLObject *o)
 {
     Uml::Object_Type ot = o->getBaseType();
@@ -380,7 +439,7 @@ Uml::Model_Type guessContainer(UMLObject *o)
             {
                 UMLAssociation *assoc = static_cast<UMLAssociation*>(o);
                 UMLDoc *umldoc = UMLApp::app()->getDocument();
-                for (int r = Uml::A; r <= Uml::B; r++) {
+                for (int r = Uml::A; r <= Uml::B; ++r) {
                     UMLObject *roleObj = assoc->getObject((Uml::Role_Type)r);
                     if (roleObj == NULL) {
                         // Ouch! we have been called while types are not yet resolved
@@ -407,6 +466,15 @@ Uml::Model_Type guessContainer(UMLObject *o)
     return mt;
 }
 
+/**
+ * Parse a direction string into the Uml::Parameter_Direction.
+ *
+ * @param input  The string to parse: "in", "out", or "inout"
+ *               optionally followed by whitespace.
+ * @param result The corresponding Uml::Parameter_Direction.
+ * @return       Length of the string matched, excluding the optional
+ *               whitespace.
+ */
 int stringToDirection(QString input, Uml::Parameter_Direction & result) 
 {
     QRegExp dirx("^(in|out|inout)");
@@ -426,6 +494,16 @@ int stringToDirection(QString input, Uml::Parameter_Direction & result)
     return dirLen;
 }
 
+/**
+ * Parses a template parameter given in UML syntax.
+ *
+ * @param t             Input text of the template parameter.
+ *                      Example:  parname : partype
+ *                      or just:  parname          (for class type)
+ * @param nmTp          NameAndType returned by this method.
+ * @param owningScope   Pointer to the owning scope of the template param.
+ * @return      Error status of the parse, PS_OK for success.
+ */
 Parse_Status parseTemplate(QString t, NameAndType& nmTp, UMLClassifier *owningScope)
 {
     UMLDoc *pDoc = UMLApp::app()->getDocument();
@@ -449,6 +527,23 @@ Parse_Status parseTemplate(QString t, NameAndType& nmTp, UMLClassifier *owningSc
     return PS_OK;
 }
 
+/**
+ * Parses an attribute given in UML syntax.
+ *
+ * @param a             Input text of the attribute in UML syntax.
+ *                      Example:  argname : argtype
+ * @param nmTp          NameAndType returned by this method.
+ * @param owningScope   Pointer to the owning scope of the attribute.
+ * @param vis           Optional pointer to visibility (return value.)
+ *                      The visibility may be given at the beginning of the
+ *                      attribute text in mnemonic form as follows:
+ *                      "+"  stands for public
+ *                      "#"  stands for protected
+ *                      "-"  stands for private
+ *                      "~"  stands for implementation level visibility
+ *
+ * @return      Error status of the parse, PS_OK for success.
+ */
 Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningScope,
                             Uml::Visibility *vis /* = 0 */)
 {
@@ -484,13 +579,13 @@ Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningS
         name.remove(mnemonicVis);
     }
     Uml::Parameter_Direction pd = Uml::pd_In;
-    if (name.startsWith("in ")) {
+    if (name.startsWith(QLatin1String("in "))) {
         pd = Uml::pd_In;
         name = name.mid(3);
-    } else if (name.startsWith("inout ")) {
+    } else if (name.startsWith(QLatin1String("inout "))) {
         pd = Uml::pd_InOut;
         name = name.mid(6);
-    } else if (name.startsWith("out ")) {
+    } else if (name.startsWith(QLatin1String("out "))) {
         pd = Uml::pd_Out;
         name = name.mid(4);
     }
@@ -514,6 +609,16 @@ Parse_Status parseAttribute(QString a, NameAndType& nmTp, UMLClassifier *owningS
     return PS_OK;
 }
 
+/**
+ * Parses an operation given in UML syntax.
+ *
+ * @param m             Input text of the operation in UML syntax.
+ *                      Example of a two-argument operation returning "void":
+ *                      methodname (arg1name : arg1type, arg2name : arg2type) : void
+ * @param desc          OpDescriptor returned by this method.
+ * @param owningScope   Pointer to the owning scope of the operation.
+ * @return      Error status of the parse, PS_OK for success.
+ */
 Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owningScope)
 {
     UMLDoc *pDoc = UMLApp::app()->getDocument();
@@ -564,8 +669,8 @@ Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owning
     arglist = arglist.trimmed();
     if (arglist.isEmpty())
         return PS_OK;
-    QStringList args = arglist.split( QRegExp("\\s*,\\s*") );
-    for (QStringList::Iterator lit = args.begin(); lit != args.end(); ++lit) {
+    const QStringList args = arglist.split( QRegExp("\\s*,\\s*") );
+    for (QStringList::ConstIterator lit = args.begin(); lit != args.end(); ++lit) {
         NameAndType nmTp;
         Parse_Status ps = parseAttribute(*lit, nmTp, owningScope);
         if (ps)
@@ -575,6 +680,15 @@ Parse_Status parseOperation(QString m, OpDescriptor& desc, UMLClassifier *owning
     return PS_OK;
 }
 
+/**
+ * Parses a constraint.
+ *
+ * @param m             Input text of the constraint
+ *
+ * @param name          The name returned by this method
+ * @param owningScope   Pointer to the owning scope of the constraint
+ * @return       Error status of the parse, PS_OK for success.
+ */
 Parse_Status parseConstraint(QString m, QString& name, UMLEntity* owningScope)
 {
     Q_UNUSED(owningScope);
@@ -592,6 +706,9 @@ Parse_Status parseConstraint(QString m, QString& name, UMLEntity* owningScope)
     return PS_OK;
 }
 
+/**
+ * Returns the Parse_Status as a text.
+ */
 QString psText(Parse_Status value)
 {
     const QString text[] = {
@@ -602,6 +719,9 @@ QString psText(Parse_Status value)
     return text[(unsigned) value];
 }
 
+/**
+ * Return string corresponding to the given Uml::Programming_Language.
+ */
 QString progLangToString(Uml::Programming_Language pl)
 {
     switch (pl) {
@@ -649,6 +769,9 @@ QString progLangToString(Uml::Programming_Language pl)
     return QString();
 }
 
+/**
+ * Return Uml::Programming_Language corresponding to the given string.
+ */
 Uml::Programming_Language stringToProgLang(QString str)
 {
     if (str == "ActionScript")
@@ -692,6 +815,11 @@ Uml::Programming_Language stringToProgLang(QString str)
     return Uml::pl_Reserved;
 }
 
+/**
+ * Return true if the listview type is one of the predefined root views
+ * (root, logical, usecase, component, deployment, datatype, or entity-
+ * relationship view.)
+ */
 bool typeIsRootView(Uml::ListView_Type type)
 {
     switch (type) {
@@ -709,6 +837,9 @@ bool typeIsRootView(Uml::ListView_Type type)
     return false;
 }
 
+/**
+ * Return true if the listview type also has a widget representation in diagrams.
+ */
 bool typeIsCanvasWidget(Uml::ListView_Type type)
 {
     switch (type) {
@@ -738,6 +869,9 @@ bool typeIsCanvasWidget(Uml::ListView_Type type)
     return false;
 }
 
+/**
+ * Return true if the listview type is a logical, usecase or component folder.
+ */
 bool typeIsFolder(Uml::ListView_Type type)
 {
     if (typeIsRootView(type) ||
@@ -753,6 +887,10 @@ bool typeIsFolder(Uml::ListView_Type type)
     }
 }
 
+/**
+ * Return true if the listview type may act as a container for other objects,
+ * i.e. if it is a folder, package, subsystem, or component.
+ */
 bool typeIsContainer(Uml::ListView_Type type)
 {
     if (typeIsFolder(type))
@@ -762,6 +900,9 @@ bool typeIsContainer(Uml::ListView_Type type)
             type == Uml::lvt_Component);
 }
 
+/**
+ * Return true if the listview type is an attribute, operation, or template.
+ */
 bool typeIsClassifierList(Uml::ListView_Type type)
 {
     if (type == Uml::lvt_Attribute ||
@@ -779,6 +920,9 @@ bool typeIsClassifierList(Uml::ListView_Type type)
     }
 }
 
+/**
+ * Return true if the listview type is a classifier ( Class, Entity , Enum )
+ */
 bool typeIsClassifier(Uml::ListView_Type type)
 {
     if ( type == Uml::lvt_Class ||
@@ -790,6 +934,9 @@ bool typeIsClassifier(Uml::ListView_Type type)
     return false;
 }
 
+/**
+ * Return true if the listview type is a diagram.
+ */
 bool typeIsDiagram(Uml::ListView_Type type)
 {
     if (type == Uml::lvt_Class_Diagram ||
@@ -807,6 +954,9 @@ bool typeIsDiagram(Uml::ListView_Type type)
     }
 }
 
+/**
+ * Return the Model_Type which corresponds to the given Diagram_Type.
+ */
 Uml::Model_Type convert_DT_MT(Uml::Diagram_Type dt)
 {
     Uml::Model_Type mt;
@@ -838,6 +988,9 @@ Uml::Model_Type convert_DT_MT(Uml::Diagram_Type dt)
     return mt;
 }
 
+/**
+ * Return the ListView_Type which corresponds to the given Model_Type.
+ */
 Uml::ListView_Type convert_MT_LVT(Uml::Model_Type mt)
 {
     Uml::ListView_Type lvt = Uml::lvt_Unknown;
@@ -863,6 +1016,11 @@ Uml::ListView_Type convert_MT_LVT(Uml::Model_Type mt)
     return lvt;
 }
 
+/**
+ * Return the Model_Type which corresponds to the given ListView_Type.
+ * Returns Uml::N_MODELTYPES if the list view type given does not map
+ * to a Model_Type.
+ */
 Uml::Model_Type convert_LVT_MT(Uml::ListView_Type lvt)
 {
     Uml::Model_Type mt = Uml::N_MODELTYPES;
@@ -888,6 +1046,9 @@ Uml::Model_Type convert_LVT_MT(Uml::ListView_Type lvt)
     return mt;
 }
 
+/**
+ * Convert a diagram type enum to the equivalent list view type.
+ */
 Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt)
 {
     Uml::ListView_Type type =  Uml::lvt_Unknown;
@@ -934,6 +1095,17 @@ Uml::ListView_Type convert_DT_LVT(Uml::Diagram_Type dt)
     return type;
 }
 
+/**
+ * Convert an object's type to the equivalent list view type
+ *
+ * @param o  Pointer to the UMLObject whose type shall be converted
+ *           to the equivalent Uml::ListView_Type.  We cannot just
+ *           pass in a Uml::Object_Type because a UMLFolder is mapped
+ *           to different Uml::ListView_Type values, depending on its
+ *           location in one of the predefined modelviews (Logical/
+ *           UseCase/etc.)
+ * @return  The equivalent Uml::ListView_Type.
+ */
 Uml::ListView_Type convert_OT_LVT(UMLObject *o)
 {
     Uml::Object_Type ot = o->getBaseType();
@@ -1065,6 +1237,13 @@ Uml::ListView_Type convert_OT_LVT(UMLObject *o)
     return type;
 }
 
+/**
+ * Converts a list view type enum to the equivalent object type.
+ *
+ * @param lvt   The ListView_Type to convert.
+ * @return  The converted Object_Type if the listview type
+ *          has a Uml::Object_Type representation, else 0.
+ */
 Uml::Object_Type convert_LVT_OT(Uml::ListView_Type lvt)
 {
     Uml::Object_Type ot = (Uml::Object_Type)0;
@@ -1162,6 +1341,13 @@ Uml::Object_Type convert_LVT_OT(Uml::ListView_Type lvt)
     return ot;
 }
 
+/**
+ * Return the Icon_Type which corresponds to the given listview type.
+ *
+ * @param lvt  ListView_Type to convert.
+ * @return  The Icon_Utils::Icon_Type corresponding to the lvt.
+ *          Returns it_Home in case no mapping to Uml::Icon_Type exists.
+ */
 Icon_Utils::Icon_Type convert_LVT_IT(Uml::ListView_Type lvt)
 {
     Icon_Utils::Icon_Type icon = Icon_Utils::it_Home;
@@ -1290,6 +1476,13 @@ Icon_Utils::Icon_Type convert_LVT_IT(Uml::ListView_Type lvt)
     return icon;
 }
 
+/**
+ * Return the Diagram_Type which corresponds to the given listview type.
+ *
+ * @param lvt  ListView_Type to convert.
+ * @return  The Uml::Diagram_Type corresponding to the lvt.
+ *          Returns dt_Undefined in case no mapping to Diagram_Type exists.
+ */
 Uml::Diagram_Type convert_LVT_DT(Uml::ListView_Type lvt)
 {
     Uml::Diagram_Type dt = Uml::dt_Undefined;
@@ -1327,6 +1520,9 @@ Uml::Diagram_Type convert_LVT_DT(Uml::ListView_Type lvt)
     return dt;
 }
 
+/**
+ * Return the Model_Type which corresponds to the given Object_Type.
+ */
 Uml::Model_Type convert_OT_MT(Uml::Object_Type ot)
 {
     Uml::Model_Type mt = Uml::N_MODELTYPES;
@@ -1357,6 +1553,10 @@ Uml::Model_Type convert_OT_MT(Uml::Object_Type ot)
     return mt;
 }
 
+/**
+ * Converts from the UpdateDeleteAction enum to a QString
+ * @param uda The UpdateDeleteAction enum literal
+ */
 QString updateDeleteActionToString( UMLForeignKeyConstraint::UpdateDeleteAction uda )
 {
     switch( uda ) {
@@ -1375,6 +1575,9 @@ QString updateDeleteActionToString( UMLForeignKeyConstraint::UpdateDeleteAction
     }
 }
 
+/**
+ * Return string corresponding to Uml::Diagram_Type
+ */
 QString diagramTypeToString(Uml::Diagram_Type dt)
 {
     switch( dt ) {
