@@ -14,6 +14,20 @@
 #include <kdebug.h>
 #include <klocale.h>
 
+UMLClassifierListItemList::UMLClassifierListItemList()
+{ }
+
+UMLClassifierListItemList::UMLClassifierListItemList(const UMLClassifierListItemList& other)
+    : QList<UMLClassifierListItem*>( other )
+{}
+
+UMLClassifierListItemList::~UMLClassifierListItemList()
+{ }
+
+/**
+ * Copy the internal presentation of this object into the new
+ * object.
+ */
 void UMLClassifierListItemList::copyInto(UMLClassifierListItemList *rhs) const {
     // Prevent copying to yourself. (Can cause serious injuries)
     if (rhs == this) return;
@@ -24,14 +38,17 @@ void UMLClassifierListItemList::copyInto(UMLClassifierListItemList *rhs) const {
     UMLClassifierListItemList *tmp = new UMLClassifierListItemList(*this);
 
     UMLClassifierListItem *item;
-    for (item = tmp->first(); item; item = tmp->next() )
-    {
+    for (UMLClassifierListItemListIt clit( *tmp ); clit.hasNext() ; ) {
+        item = clit.next();
         rhs->append((UMLClassifierListItem*)item->clone());
     }
     delete tmp;
 }
 
 
+/**
+ * Make a clone of this object.
+ */
 UMLClassifierListItemList* UMLClassifierListItemList::clone() const {
     UMLClassifierListItemList *clone = new UMLClassifierListItemList();
     copyInto(clone);
@@ -40,3 +57,6 @@ UMLClassifierListItemList* UMLClassifierListItemList::clone() const {
 
 
 
+
+
+
