@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2002-2008                                               *
+ *   copyright (C) 2002-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -31,10 +31,18 @@
 #include <kdebug.h>
 
 // qt includes
-#include <QApplication>
+#include <QtCore/QPointer>
+#include <QtGui/QApplication>
 
 using namespace Uml;
 
+/**
+ * Creates a UMLObject.
+ * @param parent   The parent of the object.
+ * @param name     The name of the object.
+ * @param id       The ID of the object (optional.) If omitted
+ *                 then a new ID will be assigned internally.
+ */
 UMLObject::UMLObject(UMLObject * parent, const QString &name, Uml::IDType id)
         : QObject(parent)
 {
@@ -47,6 +55,12 @@ UMLObject::UMLObject(UMLObject * parent, const QString &name, Uml::IDType id)
     m_Name = name;
 }
 
+/**
+ * Creates a UMLObject.
+ * @param name     The name of the object.
+ * @param id       The ID of the object (optional.) If omitted
+ *                 then a new ID will be assigned internally.
+ */
 UMLObject::UMLObject(const QString &name, Uml::IDType id)
         :  QObject(UMLApp::app()->getDocument())
 {
@@ -58,16 +72,26 @@ UMLObject::UMLObject(const QString &name, Uml::IDType id)
     m_Name = name;
 }
 
+/**
+ * Creates a UMLObject.
+ * @param   parent   The parent of the object.
+ */
 UMLObject::UMLObject(UMLObject * parent)
         : QObject(parent)
 {
     init();
 }
 
+/**
+ * Standard destructor.
+ */
 UMLObject::~UMLObject()
 {
 }
 
+/**
+ * Initializes key variables of the class.
+ */
 void UMLObject::init()
 {
     m_BaseType = Uml::ot_UMLObject;
@@ -84,12 +108,21 @@ void UMLObject::init()
     m_pSecondary = 0;
 }
 
+/**
+ * This method is called if you wish to see the properties of a
+ * UMLObject.  A dialog box will be displayed from which you
+ * can change the object's properties.
+ *
+ * @param page    The page to show.
+ * @param assoc   Whether to show association page.
+ * @return        True if we modified the object.
+ */
 bool UMLObject::showProperties(int page, bool assoc)
 {
     Q_UNUSED(page);
     DocWindow *docwindow = UMLApp::app()->getDocWindow();
     docwindow->updateDocumentation(false);
-    ClassPropDlg* dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this, assoc);
+    QPointer<ClassPropDlg> dlg = new ClassPropDlg((QWidget*)UMLApp::app(), this, assoc);
     bool modified = false;
     if (dlg->exec()) {
         docwindow->showDocumentation(this, true);
@@ -97,42 +130,78 @@ bool UMLObject::showProperties(int page, bool assoc)
         modified = true;
     }
     dlg->close();
+    delete dlg;
     return modified;
 }
 
+/**
+ * This should be reimplemented by subclasses if they wish to
+ * accept certain types of associations. Note that this only
+ * tells if this UMLObject can accept the association
+ * type. When creating an association another check is made to
+ * see if the association is valid. For example a UMLClass
+ * (UMLClassifier) can accept generalizations and should
+ * return true. If while creating a generalization the
+ * superclass is already subclassed from this, the association
+ * is not valid and will not be created.  The default accepts
+ * nothing (returns false)
+ */
 bool UMLObject::acceptAssociationType(Uml::Association_Type)
 {
     // A UMLObject accepts nothing. This should be reimplemented by the subclasses
     return false;
 }
 
+/**
+ * Assigns a new Id to the object
+ */
 void UMLObject::setID(Uml::IDType NewID)
 {
     m_nId = NewID;
     emitModified();
 }
 
+/**
+ * Set the UMLObject's name
+ */
 void UMLObject::setName(const QString &strName)
 {
     UMLApp::app()->executeCommand(new Uml::CmdRenameUMLObject(this, strName));
 }
 
+/**
+ * Method used by setName: it is called by  cmdSetName, Don't use it!
+ */
 void UMLObject::setNamecmd(const QString &strName)
 {
     m_Name = strName;
     emitModified();
 }
 
+/**
+ * Returns a copy of m_Name
+ */
 QString UMLObject::getName() const
 {
     return m_Name;
 }
 
+/**
+ * Returns the fully qualified name, i.e. all package prefixes and then m_Name.
+ *
+ * @param separator  The separator string to use (optional.)
+ *                   If not given then the separator is chosen according
+ *                   to the currently selected active programming language
+ *                   of import and code generation.
+ * @param includeRoot  Whether to prefix the root folder name to the FQN.
+ *                     See UMLDoc::getRootFolder(). Default: false.
+ * @return  The fully qualified name of this UMLObject.
+ */
 QString UMLObject::getFullyQualifiedName(const QString& separator,
         bool includeRoot /* = false */) const
 {
     QString fqn;
-    if (m_pUMLPackage) {
+    if (m_pUMLPackage && m_pUMLPackage != this) {
         bool skipPackage = false;
         if (!includeRoot) {
             UMLDoc *umldoc = UMLApp::app()->getDocument();
@@ -152,6 +221,9 @@ QString UMLObject::getFullyQualifiedName(const QString& separator,
     return fqn;
 }
 
+/**
+ * Overloaded '==' operator
+ */
 bool UMLObject::operator==(const UMLObject & rhs)
 {
     if (this == &rhs)
@@ -207,6 +279,10 @@ bool UMLObject::operator==(const UMLObject & rhs)
     return true;
 }
 
+/**
+ * Copy the internal presentation of this object into the new
+ * object.
+ */
 void UMLObject::copyInto(UMLObject *lhs) const
 {
     // Data members with copy constructor
@@ -229,11 +305,17 @@ void UMLObject::copyInto(UMLObject *lhs) const
         uDebug() << "copyInto has a wrong parent";
 }
 
+/**
+ * Returns the abstract state of the object.
+ */
 bool UMLObject::getAbstract() const
 {
     return m_bAbstract;
 }
 
+/**
+ * Sets the paste state of the object.
+ */
 void UMLObject::setAbstract(bool bAbstract)
 {
     m_bAbstract = bAbstract;
@@ -245,17 +327,29 @@ void UMLObject::setInPaste(bool bInPaste /* =true */)
     m_bInPaste = bInPaste;
 }
 
+/**
+ * Returns true if this UMLObject has classifier scope,
+ * otherwise false (the default).
+ */
 bool UMLObject::getStatic() const
 {
     return m_bStatic;
 }
 
+/**
+ * Sets the value for m_bStatic.
+ */
 void UMLObject::setStatic(bool bStatic)
 {
     m_bStatic = bStatic;
     emitModified();
 }
 
+/**
+ * Forces the emission of the modified signal.  Useful when
+ * updating several attributes at a time: you can block the
+ * signals, update all atts, and then force the signal.
+ */
 void UMLObject::emitModified()
 {
     UMLDoc *umldoc = UMLApp::app()->getDocument();
@@ -263,48 +357,95 @@ void UMLObject::emitModified()
         emit modified();
 }
 
+/**
+ * Sets the documentation for the object.
+ *
+ * @param d The documentation for the object.
+ */
 void UMLObject::setDoc(const QString &d)
 {
     m_Doc = d;
     //emit modified();  No, this is done centrally at DocWindow::updateDocumentation()
 }
 
+/**
+ * Returns the type of the object.
+ *
+ * @return  Returns the type of the object.
+ */
 Uml::Object_Type UMLObject::getBaseType() const
 {
     return m_BaseType;
 }
 
+/**
+ * Set the type of the object.
+ *
+ * @param ot The Uml::Object_Type to set.
+ */
 void UMLObject::setBaseType(Uml::Object_Type ot)
 {
     m_BaseType = ot;
 }
 
+/**
+ * Returns the ID of the object.
+ *
+ * @return  Returns the ID of the object.
+ */
 Uml::IDType UMLObject::getID() const
 {
     return m_nId;
 }
 
+/**
+ * Returns the documentation for the object.
+ *
+ * @return  Returns the documentation for the object.
+ */
 QString UMLObject::getDoc() const
 {
     return m_Doc;
 }
 
+/**
+ * Returns the visibility of the object.
+ *
+ * @return  Returns the visibility of the object.
+ */
 Uml::Visibility UMLObject::getVisibility() const
 {
     return m_Vis;
 }
 
+/**
+ * Sets the visibility of the object.
+ *
+ * @param s   The visibility of the object.
+ */
 void UMLObject::setVisibility(Uml::Visibility s)
 {
     UMLApp::app()->executeCommand(new CmdSetVisibility(this, s));
 }
 
+/**
+ * Method used by setVisibility: it is called by  cmdSetVisibility, Don't use it!
+ */
 void UMLObject::setVisibilitycmd(Uml::Visibility s)
 {
     m_Vis = s;
     emitModified();
 }
 
+/**
+ * Sets the class' UMLStereotype. Adjusts the reference counts
+ * at the previously set stereotype and at the new stereotype.
+ * If the previously set UMLStereotype's reference count drops
+ * to zero then the UMLStereotype is removed at the UMLDoc and
+ * it is then physically deleted.
+ *
+ * @param stereo Sets the classes UMLStereotype.
+ */
 void UMLObject::setUMLStereotype(UMLStereotype *stereo)
 {
     if (stereo == m_pStereotype)
@@ -325,6 +466,12 @@ void UMLObject::setUMLStereotype(UMLStereotype *stereo)
     emitModified();
 }
 
+/**
+ * Sets the classes stereotype name.
+ * Internally uses setUMLStereotype().
+ *
+ * @param _name     Sets the classes stereotype name.
+ */
 void UMLObject::setStereotype(const QString &_name)
 {
     // UMLDoc* pDoc = UMLApp::app()->getDocument();
@@ -343,6 +490,12 @@ void UMLObject::setStereotypecmd(const QString& /*_name*/)
 //TODO: put SetStereotype into QundoStack
 }
 
+/**
+ * Sets the classes Package.
+ * DEPRECATED - use SetUMLPackage instead.
+ *
+ * @param _name   The classes Package name.
+ */
 void UMLObject::setPackage(const QString &_name)
 {
     UMLObject *pkgObj = NULL;
@@ -365,17 +518,30 @@ void UMLObject::setPackage(const QString &_name)
     setUMLPackage(static_cast<UMLPackage *>(pkgObj));
 }
 
+/**
+ * Sets the UMLPackage in which this class is located.
+ *
+ * @param pPkg   Pointer to the class' UMLPackage.
+ */
 void UMLObject::setUMLPackage(UMLPackage* pPkg)
 {
     m_pUMLPackage = pPkg;
     emitModified();
 }
 
+/**
+ * Returns the classes UMLStereotype object.
+ *
+ * @return   Returns the classes UMLStereotype object.
+ */
 const UMLStereotype * UMLObject::getUMLStereotype()
 {
     return m_pStereotype;
 }
 
+/**
+ * Returns the stereotype.
+ */
 QString UMLObject::getStereotype(bool includeAdornments /* = false */) const
 {
     if (m_pStereotype == NULL)
@@ -386,6 +552,18 @@ QString UMLObject::getStereotype(bool includeAdornments /* = false */) const
     return name;
 }
 
+/**
+ * Return the package(s) in which this UMLObject is contained
+ * as a text.
+ *
+ * @param separator Separator string for joining together the
+ *                  individual package prefixes (optional.)
+ *                  If no separator is given then the separator
+ *                  of the currently selected language is used.
+ * @param includeRoot  Whether to prefix the root folder name.
+ *                     Default: false.
+ * @return  The UMLObject's enclosing package(s) as a text.
+ */
 QString UMLObject::getPackage(const QString& separator, bool includeRoot)
 {
     QString tempSeparator = separator;
@@ -398,6 +576,14 @@ QString UMLObject::getPackage(const QString& separator, bool includeRoot)
     return scope;
 }
 
+/**
+ * Return a list of the packages in which this class is embedded.
+ * The outermost package is first in the list.
+ *
+ * @param includeRoot  Whether to prefix the root folder name.
+ *                     Default: false.
+ * @return  UMLPackageList of the containing packages.
+ */
 UMLPackageList UMLObject::getPackages(bool includeRoot) const
 {
     UMLPackageList pkgList;
@@ -411,31 +597,56 @@ UMLPackageList UMLObject::getPackages(bool includeRoot) const
     return pkgList;
 }
 
+/**
+ * Returns the UMLPackage that this class is located in.
+ *
+ * @return  Pointer to the UMLPackage of this class.
+ */
 UMLPackage* UMLObject::getUMLPackage()
 {
     return m_pUMLPackage;
 }
 
+/**
+ * Return secondary ID. Required by resolveRef().
+ */
 QString UMLObject::getSecondaryId() const
 {
     return m_SecondaryId;
 }
 
+/**
+ * Set the secondary ID.
+ * Currently only required by petalTree2Uml(); all other setting of the
+ * m_SecondaryID is internal to the UMLObject class hierarchy.
+ */
 void UMLObject::setSecondaryId(const QString& id)
 {
     m_SecondaryId = id;
 }
 
+/**
+ * Return secondary ID fallback.
+ * Required by resolveRef() for imported model files.
+ */
 QString UMLObject::getSecondaryFallback() const
 {
     return m_SecondaryFallback;
 }
 
+/**
+ * Set the secondary ID fallback.
+ * Currently only used by petalTree2Uml().
+ */
 void UMLObject::setSecondaryFallback(const QString& id)
 {
     m_SecondaryFallback = id;
 }
 
+/**
+ * Calls UMLDoc::signalUMLObjectCreated() if m_BaseType affords
+ * doing so.
+ */
 void UMLObject::maybeSignalObjectCreated()
 {
     if (!m_bCreationWasSignalled &&
@@ -448,6 +659,17 @@ void UMLObject::maybeSignalObjectCreated()
     }
 }
 
+/**
+ * Resolve referenced objects (if any.)
+ * Needs to be called after all UML objects are loaded from file.
+ * This needs to be done after all model objects are loaded because
+ * some of the xmi.id's might be forward references, i.e. they may
+ * identify model objects which were not yet loaded at the point of
+ * reference.
+ * The default implementation attempts resolution of the m_SecondaryId.
+ *
+ * @return   True for success.
+ */
 bool UMLObject::resolveRef()
 {
     if (m_pSecondary || (m_SecondaryId.isEmpty() && m_SecondaryFallback.isEmpty())) {
@@ -541,6 +763,12 @@ bool UMLObject::resolveRef()
     return true;
 }
 
+/**
+ * Auxiliary to saveToXMI.
+ * Create a QDomElement with the given tag, and save the XMI attributes
+ * that are common to all child classes to the newly created element.
+ * This method does not need to be overridden by child classes.
+ */
 QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
 {
     /*
@@ -589,6 +817,12 @@ QDomElement UMLObject::save(const QString &tag, QDomDocument & qDoc)
     return qElement;
 }
 
+/**
+ * Auxiliary to loadFromXMI.
+ * This method is usually overridden by child classes.
+ * It is responsible for loading the specific XMI structure
+ * of the child class.
+ */
 bool UMLObject::load(QDomElement&)
 {
     // This body is not usually executed because child classes
@@ -596,6 +830,12 @@ bool UMLObject::load(QDomElement&)
     return true;
 }
 
+/**
+ * Analyzes the given QDomElement for a reference to a stereotype.
+ *
+ * @param element   QDomElement to analyze.
+ * @return          True if a stereotype reference was found, else false.
+ */
 bool UMLObject::loadStereotype(QDomElement & element)
 {
     QString tag = element.tagName();
@@ -627,6 +867,14 @@ bool UMLObject::loadStereotype(QDomElement & element)
     return true;
 }
 
+/**
+ * This method loads the generic parts of the XMI common to most model
+ * classes.  It is not usually reimplemented by child classes.
+ * Instead, it invokes the load() method which implements the loading
+ * of the specifics of each child class.
+ *
+ * @param element   The QDomElement from which to load.
+ */
 bool UMLObject::loadFromXMI(QDomElement & element)
 {
     UMLDoc* umldoc = UMLApp::app()->getDocument();
