@@ -4,7 +4,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2006-2008                                               *
+ *   copyright (C) 2006-2009                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -42,25 +42,39 @@
 static QStringList supportedImageTypesList;
 static QStringList supportedMimeTypesList;
 
+/**
+ * Returns a QStringList containing all the supported image types to use when exporting.
+ * All the types will be lower case.
+ *
+ * @return A QStringList containing all the supported image types to use when exporting.
+ */
 QStringList UMLViewImageExporterModel::supportedImageTypes()
 {
     if (!supportedImageTypesList.size()) {
-        // specific supported formats
-        supportedImageTypesList << "eps";
-        supportedImageTypesList << "svg";
-
         // QT supported formats
         QList<QByteArray> qImageFormats = QImageWriter::supportedImageFormats();
-        QList<QByteArray>::const_iterator it, it_end;
-        it = qImageFormats.begin(); it_end = qImageFormats.end();
-        for (; it != it_end; ++it) {
-            supportedImageTypesList << QString(*it).toLower();
+        Q_FOREACH(const QByteArray& it, qImageFormats) {
+            const QString format = it.toLower();
+            if (!supportedImageTypesList.contains(format))
+                supportedImageTypesList << format;
         }
+        // specific supported formats
+        if (!supportedImageTypesList.contains("eps"))
+            supportedImageTypesList << "eps";
+        if (!supportedImageTypesList.contains("svg"))
+            supportedImageTypesList << "svg";
     }
+    supportedImageTypesList.sort();
 
     return supportedImageTypesList;
 }
 
+/**
+ * Returns a QStringList containing all the supported mime types to use when exporting.
+ * All the types will be lower case.
+ *
+ * @return A QStringList containing all the supported mime types to use when exporting.
+ */
 QStringList UMLViewImageExporterModel::supportedMimeTypes()
 {
     if (!supportedMimeTypesList.size()) {
@@ -75,6 +89,14 @@ QStringList UMLViewImageExporterModel::supportedMimeTypes()
     return supportedMimeTypesList;
 }
 
+/**
+ * Returns the mime type for an image type.
+ * The supported image types are those that the diagrams can be exported to.
+ *
+ * @param imageType The type of the image.
+ * @return A QString with the equivalent mime type, or QString() if
+ *         it's unknown.
+ */
 QString UMLViewImageExporterModel::imageTypeToMimeType(const QString& imageType)
 {
     const QString imgType = imageType.toLower();
@@ -91,6 +113,14 @@ QString UMLViewImageExporterModel::imageTypeToMimeType(const QString& imageType)
     return QString();
 }
 
+/**
+ * Returns the image type for a mime type.
+ * The supported image types are those that the diagrams can be exported to.
+ *
+ * @param mimeType The mime type.
+ * @return A lowercase QString with the equivalent image type, or QString()
+ *         if it's unknown.
+ */
 QString UMLViewImageExporterModel::mimeTypeToImageType(const QString& mimeType)
 {
     if (QString("image/bmp") == mimeType) return "bmp";
@@ -106,6 +136,42 @@ QString UMLViewImageExporterModel::mimeTypeToImageType(const QString& mimeType)
     return QString();
 }
 
+/**
+ * Constructor for UMLViewImageExporterModel.
+ */
+UMLViewImageExporterModel::UMLViewImageExporterModel()
+{
+}
+
+/**
+ * Destructor for UMLViewImageExporterModel.
+ */
+UMLViewImageExporterModel::~UMLViewImageExporterModel()
+{
+}
+
+/**
+ * Exports all the views in the document to the directory specified in the url
+ * using the 'imageType' for the images.
+ * The name of the exported images will be like their view's name and using the
+ * 'imageType' as extension.
+ *
+ * The views are stored in folders in the document. The same tree structure used
+ * in the document to store the views can be created in the target directory with
+ * 'useFolders'. Only the folders made by the user are created in the target
+ * directory (Logical view, use case view and so on aren't created).
+ *
+ * This method creates the specified target directory if needed. If there was an
+ * existing file with the same path as one to be created overwrites it without asking.
+ * The url used can be local or remote, using supported KIO slaves.
+ *
+ * @param imageType The type of the images the views will be exported to.
+ * @param directory The url of the directory where the images will be saved.
+ * @param useFolders If the tree structure of the views in the document must be created
+ *                   in the target directory.
+ * @return A QStringList with all the error messages that occurred during export.
+ *         If the list is empty, all the views were exported successfully.
+ */
 QStringList UMLViewImageExporterModel::exportAllViews(const QString &imageType, const KUrl &directory, bool useFolders) const
 {
     UMLApp *app = UMLApp::app();
@@ -127,6 +193,21 @@ QStringList UMLViewImageExporterModel::exportAllViews(const QString &imageType,
     return errors;
 }
 
+/**
+ * Exports the view to the url using the 'imageType' for the image.
+ *
+ * This method creates the needed directories, if any. If there was an existing
+ * file in the specified url overwrites it without asking.
+ * The url used can be local or remote, using supported KIO slaves.
+ *
+ * If some problem occurs when exporting, an error message is returned.
+ *
+ * @param view The view to export.
+ * @param imageType The type of the image the view will be exported to.
+ * @param url The url where the image will be saved.
+ * @return The message error if some problem occurred when exporting, or
+ *         QString() if all went fine.
+ */
 QString UMLViewImageExporterModel::exportView(UMLView* view, const QString &imageType, const KUrl &url) const
 {
     // create the needed directories
@@ -140,7 +221,7 @@ QString UMLViewImageExporterModel::exportView(UMLView* view, const QString &imag
     QString fileName;
     KTemporaryFile tmpFile;
     if (url.isLocalFile()) {
-        fileName = url.path();
+        fileName = url.toLocalFile();
     } else {
         tmpFile.open();
         fileName = tmpFile.fileName();
@@ -167,6 +248,13 @@ QString UMLViewImageExporterModel::exportView(UMLView* view, const QString &imag
     return QString();
 }
 
+/**
+ * Returns the diagram file name.
+ * @param view         the diagram
+ * @param imageType    the image type as file name extension
+ * @param useFolders   flag whether to add folder to the file name
+ * @return the file name with extension
+ */
 QString UMLViewImageExporterModel::getDiagramFileName(UMLView *view, const QString &imageType, bool useFolders /* = false */) const
 {
     QString name = view->getName() + '.' + imageType.toLower();
@@ -193,6 +281,14 @@ QString UMLViewImageExporterModel::getDiagramFileName(UMLView *view, const QStri
     return name;
 }
 
+/**
+ * Creates, if it doesn't exist, the directory to save the file.
+ * It also creates all the needed parent directories.
+ *
+ * @param url The url where the image will be saved.
+ * @return True if the operation was successful,
+ *         false if the directory didn't exist and couldn't be created.
+ */
 bool UMLViewImageExporterModel::prepareDirectory(const KUrl &url) const
 {
     // the KUrl is copied to get protocol, user and so on and then the path is cleaned
@@ -201,7 +297,7 @@ bool UMLViewImageExporterModel::prepareDirectory(const KUrl &url) const
 
     // creates the directory and any needed parent directories
     QStringList dirs = url.directory().split(QDir::separator(), QString::SkipEmptyParts );
-    for (QStringList::ConstIterator it = dirs.begin() ; it != dirs.end(); ++it) {
+    for (QStringList::ConstIterator it = dirs.constBegin() ; it != dirs.constEnd(); ++it) {
         directory.addPath(*it);
 
         if (!KIO::NetAccess::exists(directory, KIO::NetAccess::SourceSide, UMLApp::app())) {
@@ -215,6 +311,15 @@ bool UMLViewImageExporterModel::prepareDirectory(const KUrl &url) const
     return true;
 }
 
+/**
+ * Exports the view to the file 'fileName' as the specified type.
+ *
+ * @param view The view to export.
+ * @param imageType The type of the image the view will be exported to.
+ * @param fileName The name of the file where the image will be saved.
+ * @return True if the operation was successful,
+ *         false if a problem occurred while exporting.
+ */
 bool UMLViewImageExporterModel::exportViewTo(UMLView* view, const QString &imageType, const QString &fileName) const
 {
     // remove 'blue squares' from exported picture.
@@ -238,6 +343,16 @@ bool UMLViewImageExporterModel::exportViewTo(UMLView* view, const QString &image
     return true;
 }
 
+/**
+ * Exports the view to the file 'fileName' as EPS.
+ *
+ * @param view The view to export.
+ * @param fileName The name of the file where the image will be saved.
+ * @param isEPS The file is an eps file and needs adjusting
+ *              of the eps bounding box values.
+ * @return True if the operation was successful,
+ *         false if a problem occurred while exporting.
+ */
 bool UMLViewImageExporterModel::exportViewToEps(UMLView* view, const QString &fileName, bool isEPS) const
 {
     bool exportSuccessful = true;
@@ -269,8 +384,8 @@ bool UMLViewImageExporterModel::exportViewToEps(UMLView* view, const QString &fi
     view->forceUpdateWidgetFontMetrics(painter);
 
     QRect rect = view->getDiagramRect();
-    painter->translate(-rect.x(),-rect.y());
-    view->getDiagram(rect,*painter);
+    painter->translate(-rect.x(), -rect.y());
+    view->getDiagram(rect, *painter);
 
     int resolution = printer->resolution();
 
@@ -281,7 +396,7 @@ bool UMLViewImageExporterModel::exportViewToEps(UMLView* view, const QString &fi
         // modify bounding box from screen to eps resolution.
         rect.setWidth( int(ceil(rect.width() * 72.0/resolution)) );
         rect.setHeight( int(ceil(rect.height() * 72.0/resolution)) );
-        exportSuccessful = fixEPS(fileName,rect);
+        exportSuccessful = fixEPS(fileName, rect);
     }
     // next painting will most probably be to a different device (i.e. the screen)
     view->forceUpdateWidgetFontMetrics(0);
@@ -289,6 +404,14 @@ bool UMLViewImageExporterModel::exportViewToEps(UMLView* view, const QString &fi
     return exportSuccessful;
 }
 
+/**
+ * Fix the file 'fileName' to be a valid EPS containing the
+ * specified area (rect) of the diagram.
+ * Corrects the bounding box.
+ *
+ * @return True if the operation was successful,
+ *         false if a problem occurred while exporting.
+ */
 bool UMLViewImageExporterModel::fixEPS(const QString &fileName, const QRect& rect) const
 {
     // now open the file and make a correct eps out of it
@@ -334,6 +457,14 @@ bool UMLViewImageExporterModel::fixEPS(const QString &fileName, const QRect& rec
     return true;
 }
 
+/**
+ * Exports the view to the file 'fileName' as SVG.
+ *
+ * @param view The view to export.
+ * @param fileName The name of the file where the image will be saved.
+ * @return True if the operation was successful,
+ *         false if a problem occurred while exporting.
+ */
 bool UMLViewImageExporterModel::exportViewToSvg(UMLView* view, const QString &fileName) const
 {
     bool exportSuccessful;
@@ -364,6 +495,16 @@ bool UMLViewImageExporterModel::exportViewToSvg(UMLView* view, const QString &fi
     return exportSuccessful;
 }
 
+/**
+ * Exports the view to the file 'fileName' as a pixmap of the specified type.
+ * The valid types are those supported by QPixmap save method.
+ *
+ * @param view The view to export.
+ * @param imageType The type of the image the view will be exported to.
+ * @param fileName The name of the file where the image will be saved.
+ * @return True if the operation was successful,
+ *         false if a problem occurred while exporting.
+ */
 bool UMLViewImageExporterModel::exportViewToPixmap(UMLView* view, const QString &imageType, const QString &fileName) const
 {
     bool exportSuccessful;
